/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 1997, 2001 - All Rights Reserved                */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */

package com.ibm.osg.sample.handlesecurity;

/**
 * The <code>BASE64</code> class implement encoding/decoding of BASE64 strings
 *
 */
public class BASE64 {

	/*
	 * Static variables:
	 */


	/**
	 * rfc-521: Base64 Alphabet
	 */
	private static byte[]  encodeMap = {
	   (byte)'A', (byte)'B', (byte)'C', (byte)'D', (byte)'E', (byte)'F',
	   (byte)'G', (byte)'H', (byte)'I', (byte)'J', (byte)'K', (byte)'L',
	   (byte)'M', (byte)'N', (byte)'O', (byte)'P', (byte)'Q', (byte)'R',
	   (byte)'S', (byte)'T', (byte)'U', (byte)'V', (byte)'W', (byte)'X',
	   (byte)'Y', (byte)'Z',
	   (byte)'a', (byte)'b', (byte)'c', (byte)'d', (byte)'e', (byte)'f',
	   (byte)'g', (byte)'h', (byte)'i', (byte)'j', (byte)'k', (byte)'l',
	   (byte)'m', (byte)'n', (byte)'o', (byte)'p', (byte)'q', (byte)'r',
	   (byte)'s', (byte)'t', (byte)'u', (byte)'v', (byte)'w', (byte)'x',
	   (byte)'y', (byte)'z',
	   (byte)'0', (byte)'1', (byte)'2', (byte)'3', (byte)'4', (byte)'5',
	   (byte)'6', (byte)'7', (byte)'8', (byte)'9', (byte)'+', (byte)'/'
	};
	private static byte[]  decodeMap;



	/* Class Initializer, build the decode map array*/

	static {	
	   decodeMap = new byte[128];
	   for (int idx=0; idx<encodeMap.length; idx++)
		  decodeMap[encodeMap[idx]] = (byte) idx;
	}

	/*
	 * Constructor(s):
	 */

	/**
	 * This class isn't meant to be instantiated.
	 *
	 */
	private BASE64() {
		super();
	}
	/**
	 * This method decodes the given byte[] using the base64-encoding
	 * specified in RFC-1521 (Section 5.2).
	 *
	 * @param  data the base64-encoded data.
	 * @return the decoded <var>data</var>.
	 */
	public static byte[] decode(byte[] data)
	{
		if (data == null)  return  null;

		int tail = data.length;
		while (data[tail-1] == '=')  tail--;

		byte dest[] = new byte[tail - data.length/4];


		// ascii printable to 0-63 conversion
		for (int idx = 0; idx <data.length; idx++)
			data[idx] = decodeMap[data[idx]];

		// 4-byte to 3-byte conversion
		int sidx, didx;
		for (sidx = 0, didx=0; didx < dest.length-2; sidx += 4, didx += 3)
		{
			dest[didx]   = (byte) ( ((data[sidx] << 2) & 255) |
							((data[sidx+1] >>> 4) & 003) );
			dest[didx+1] = (byte) ( ((data[sidx+1] << 4) & 255) |
							((data[sidx+2] >>> 2) & 017) );
			dest[didx+2] = (byte) ( ((data[sidx+2] << 6) & 255) |
							(data[sidx+3] & 077) );
		}
		if (didx < dest.length)
			dest[didx]   = (byte) ( ((data[sidx] << 2) & 255) |
							((data[sidx+1] >>> 4) & 003) );
		if (++didx < dest.length)
			dest[didx]   = (byte) ( ((data[sidx+1] << 4) & 255) |
							((data[sidx+2] >>> 2) & 017) );

		return dest;
	}
	/**
	 * This method decodes the given string using the base64-encoding
	 * specified in RFC-1521 (Section 5.2).
	 *
	 * @param  str the base64-encoded string.
	 * @return the decoded <var>str</var>.
	 */
	public static String decode(String str)
	{
		if (str == null)  return  null;

		//byte data[] = new byte[str.length()];
		//str.getBytes(0, str.length(), data, 0);
		byte data[] = str.getBytes();

		//return new String(base64Decode(data), 0);
		return new String(decode(data));
	}
	/**
	 * This method encodes the given byte[] using the base64-encoding
	 * specified in RFC-1521 (Section 5.2).
	 *
	 * @param  data the data
	 * @return the base64-encoded <var>data</var>
	 */
	public static byte[] encode(byte[] data)
	{
		if (data == null)  return  null;

		int sidx, didx;
		byte dest[] = new byte[((data.length+2)/3)*4];


		// 3-byte to 4-byte conversion + 0-63 to ascii printable conversion
		for (sidx=0, didx=0; sidx < data.length-2; sidx += 3)
		{
			dest[didx++] = encodeMap[(data[sidx] >>> 2) & 077];
			dest[didx++] = encodeMap[(data[sidx+1] >>> 4) & 017 |
										(data[sidx] << 4) & 077];
			dest[didx++] = encodeMap[(data[sidx+2] >>> 6) & 003 |
										(data[sidx+1] << 2) & 077];
			dest[didx++] = encodeMap[data[sidx+2] & 077];
		}
		if (sidx < data.length)
		{
			dest[didx++] = encodeMap[(data[sidx] >>> 2) & 077];
			if (sidx < data.length-1)
			{
				dest[didx++] = encodeMap[(data[sidx+1] >>> 4) & 017 |
											(data[sidx] << 4) & 077];
				dest[didx++] = encodeMap[(data[sidx+1] << 2) & 077];
			}
			else
				dest[didx++] = encodeMap[(data[sidx] << 4) & 077];
		}

		// add padding
		for ( ; didx < dest.length; didx++)
			dest[didx] = (byte) '=';

		return dest;
	}
	/*
	 * Methods:
	 */

	/**
	 * This method encodes the given string using the base64-encoding
	 * specified in RFC-1521 (Section 5.2). It's used for example in the
	 * "Basic" authorization scheme.
	 *
	 * @param  str the string
	 * @return the base64-encoded <var>str</var>
	 */
	public static String encode(String str)
	{
		if (str == null)  return  null;

		//byte data[] = new byte[str.length()];
		//str.getBytes(0, str.length(), data, 0);
		byte data[] = str.getBytes();

		//return new String(base64Encode(data), 0);
		return new String(encode(data));
	}
}
