/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2001 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */

package com.ibm.osg.sample.handlesecurity;

import org.osgi.framework.*;
import java.util.*;

/**
 *  This class registers a service with the HttpContext interface name and the
 *  "com.ibm.osg.service.http.default.handleSecurity" property.  If the IBM Http Service
 *  implementation finds a service registered with these characteristics, it gets the service and
 *  uses it as its handleSecurity plugin.  The handleSecurity plugin is used by the IBM Http Service
 *  implementation to define the default behaviour for the default HttpContext's handleSecurity method.
 */

public class HandleSecurityActivator implements org.osgi.framework.BundleActivator
{
    /* Name of HttpContext interface. */
    static protected final String pluginClazz = "org.osgi.service.http.HttpContext";

    /* Name of property used when registering the HandleSecurity service. */
    static protected final String pluginProperty = "com.ibm.osg.service.http.default.handleSecurity";

    protected ServiceRegistration reg;

    /**
     * Part of the BundleActivator interface. This method starts
     * the bundle and must quickly return. If the bundle requires
     * its own threads. they can be created here. If the bundle
     * registers any Services, they can be registered here.
     *
     * @param   context BundleContext object for this bundle
     */

    public void start(BundleContext context)
    {
        Hashtable props = new Hashtable(5);
        props.put(pluginProperty, "");
        reg = context.registerService(pluginClazz, new HandleSecurity(context), props);
    }

    /**
     * Part of the BundleActivator interface. This method stops
     * the bundle and must quickly return. If the bundle registered any
     * Services they should be unregistered here.
     *
     * @param   context BundleContext object for this bundle
     */
    public void stop(BundleContext context)
    {
        reg.unregister();
    }
}