/*
 * IBM Confidential
 *
 * OCO Source Materials
 *
 * 0000-000
 *
 * (C) Copyright IBM Corp. 2002.
 *
 * The source code for this program is not published or other-
 * wise divested of its trade secrets, irrespective of what has
 * been deposited with the U. S. Copyright Office.
 */

package com.ibm.osg.sample.simpledriverlocator;
import javax.xml.parsers.*;
import org.xml.sax.*;
import java.io.*;
import java.security.*;

/**
 * DataParser is responsible for parsing a driverlocator.properties file.  
 * It uses the SimpleDriverLocatorData class to respesent the parsed data.
 *
 *<?xml version="1.0" encoding="UTF-8"?>
 *  <driverlocator>
 *   <devicepropertypair property="FooAppliances" value="Oven">
 *     	<driveridlocation driverID="343Oven" driverLocation="http://www.foo.com/drivers/343Oven" />
 *      <driveridlocation driverID="293Oven" driverLocation="http://www.foo.com/drivers/293Oven" />
 *   </devicepropertypair>
 *   <devicepropertypair property="FooAppliances" value="Toaster">
 *   	<driveridlocation driverID="400Toaster" driverLocation="http://www.foo.com/drivers/400Toaster" />
 *   </devicepropertypair>
 * </driverlocator>
 *
 * @version 1.0
 */

public class DataParser
{
    private static final boolean DEBUG = false;
    protected Locator locator;
    protected org.xml.sax.Parser parser;
    
    static protected final String filename = "/driverlocator.properties";
    
    private final String devicepropertypair = "devicepropertypair";
    private final String driveridlocation = "driveridlocation";
    private final String driverlocator = "driverlocator";
    
    private SimpleDriverLocatorData data;
    
    
    public DataParser(SimpleDriverLocatorData data, SAXParserFactory parserFactory)
    {
     	this.data = data;
        try 
        {
            try
            {
                parserFactory.setValidating(false);
                SAXParser saxParser = parserFactory.newSAXParser();
                parser = saxParser.getParser();
                parser.setDocumentHandler(new RootHandler());
                // must encapuslate the file access inside a doPrivileged in case anyone on the call stack does not have enough permissions
                AccessController.doPrivileged(new PrivilegedExceptionAction() {
                        public java.lang.Object run() throws IOException, SAXException {
                            InputStream is = getClass().getResourceAsStream(filename);
                            InputSource isource = new InputSource(is);
                            parser.parse(isource);
                            return null;
                        }
                        });
            }
            
            catch (PrivilegedActionException pae) {
                throw (Exception)pae.getException();
            }
            
            catch (SAXParseException exc)
            {
                System.err.println("Parser exception on line "+exc.getLineNumber()+", column "+exc.getColumnNumber());

                throw exc;
            }
            catch (IllegalArgumentException exc)
            {
                System.err.println("SimpleDriverLocator can not find it's configutation file");
                System.err.println("Configuration file shold be " + filename + " located in the SimpleDriverLocator bundle");
             
            }
        }
        catch (Exception e)
        {
            e.printStackTrace();          
        }
    }

    /**
     * Handler for the root element. It's only child must be the "driverlocator" element.
     */
    private class RootHandler extends HandlerBase
    {
        public RootHandler()
        {
        	super();
        }
        
        public void startElement(String tag, AttributeList attrs) throws SAXParseException
        {
            if (tag.equals(driverlocator))
            {
                new DriverLocatorHandler(this).init(tag, attrs);
            }
            else
            {
                throw new SAXParseException("Unexpected element \"" + tag + "\"", locator);
            }
        }
        
         public void setDocumentLocator(Locator locator)
        {
            DataParser.this.locator = locator;
        }
    }

    /**
     * The common superclass for all sax event handlers in Ant. Basically
     * throws an exception in each method, so subclasses should override
     * what they can handle.
     *
     * Each type of xml element (task, target, etc) in ant will
     * have its own subclass of AbstractHandler.
     *
     * In the constructor, this class    takes over the handling of sax
     * events from the parent handler, and returns
     * control back to the parent in the endElement method.
     */
    private class AbstractHandler extends HandlerBase
    {
        protected DocumentHandler parentHandler;

        public AbstractHandler(DocumentHandler parentHandler)
        {
            this.parentHandler = parentHandler;

            // Start handling SAX events
            parser.setDocumentHandler(this);
        }

        public void startElement(String tag, AttributeList attrs) throws SAXParseException
        {
            throw new SAXParseException("Unexpected element \"" + tag + "\"", locator);
        }

        public void characters(char[] buf, int start, int end) throws SAXParseException
        {
            String s = new String(buf, start, end).trim();

            if (s.length() > 0)
            {
                throw new SAXParseException("Unexpected text \"" + s + "\"", locator);
            }
        }

        /**
         * Called when this element and all elements nested into it have been
         * handled.
         */
        protected void finished()
        {
        }

        public void endElement(String name) throws SAXException
        {
            finished();
            // Let parent resume handling SAX events
            parser.setDocumentHandler(parentHandler);
        }
    }

    /**
     * Handler for the "driverlocator" element
     */
    private class DriverLocatorHandler extends AbstractHandler
    {
        public DriverLocatorHandler(DocumentHandler parentHandler)
        {
            super(parentHandler);
        }

        public void init(String tag, AttributeList attrs) throws SAXParseException
        {

        }

        public void startElement(String tag, AttributeList attrs) throws SAXParseException
        {
            if (tag.equals(devicepropertypair))
            {
                new DevicePropertyPairHandler(this).init(tag, attrs);
            }
            else
            {
                throw new SAXParseException("Unexpected element \"" + tag + "\"", locator);
            }
        }
    }

    /**
     * Handler for the "devicepropertypair" element
     */
    private class DevicePropertyPairHandler extends AbstractHandler
    {
        protected PropertyValuePair valuePair;
        
        public DevicePropertyPairHandler(DocumentHandler parentHandler)
        {
            super(parentHandler);
        }

        public void init(String tag, AttributeList attrs) throws SAXParseException
        {
        	if (DEBUG)
            {
                System.err.print(tag+":");
            }

            int size = attrs.getLength();
            for (int i = 0; i < size; i++)
            {
                String propertyNameKey = attrs.getName(i);
                if(!propertyNameKey.equals("property"))
                {
                	throw new SAXParseException("Unexpected element \"" + tag + "\"", locator);
                }
                String propertyName = attrs.getValue(i); 
                i++;
                if(i > size)
                {
                	throw new SAXParseException("Unexpected end of tag \"" + tag + "\"", locator);
                }
                String propertyValueKey = attrs.getName(i);
                if(!propertyValueKey.equals("value"))
                {
                	throw new SAXParseException("Unexpected element \"" + tag + "\"", locator);
                }
                String propertyValue = attrs.getValue(i); 
            	valuePair = data.addPropertyValue(propertyName.toUpperCase(),propertyValue.toUpperCase());
            }
            if (DEBUG)
            {
                System.err.println();
            }
        
        }

        public void startElement(String tag, AttributeList attrs) throws SAXParseException
        {
            if (tag.equals(driveridlocation))
            {
                new DriverIDHandler(this).init(tag, attrs);
            }
            else
            {
                throw new SAXParseException("Unexpected element \"" + tag + "\"", locator);
            }
        }
    }

    /**
     * Handler for the "project" element
     *          <project path="/SharedProject1"/>
     */
    private class DriverIDHandler extends AbstractHandler
    {
        
        public DriverIDHandler(DocumentHandler parentHandler)
        {
            super(parentHandler);
        }

        public void init(String tag, AttributeList attrs) throws SAXParseException
        {
            if (DEBUG)
            {
                System.err.print(tag+":");
            }

            int size = attrs.getLength();
            for (int i = 0; i < size; i++)
            {
                String driverIDKey = attrs.getName(i);
                if(!driverIDKey.equals("driverID"))
                {
                	throw new SAXParseException("Unexpected element \"" + tag + "\"", locator);
                }
                String driverID = attrs.getValue(i); 
                i++;
                if(i > size)
                {
                	throw new SAXParseException("Unexpected end of tag \"" + tag + "\"", locator);
                }
                String driverLocationKey = attrs.getName(i);
                if(!driverLocationKey.equals("driverLocation"))
                {
                	throw new SAXParseException("Unexpected element \"" + tag + "\"", locator);
                }
                String url = attrs.getValue(i); 
            	data.addDrivertoPropValue(((DevicePropertyPairHandler)parentHandler).valuePair,driverID,url);            
            	            }
            if (DEBUG)
            {
                System.err.println();
            }

        }
    }

}
