/*
 * IBM Confidential
 *
 * OCO Source Materials
 *
 * 0000-000
 *
 * (C) Copyright IBM Corp. 2002.
 *
 * The source code for this program is not published or other-
 * wise divested of its trade secrets, irrespective of what has
 * been deposited with the U. S. Copyright Office.
 */


package com.ibm.osg.sample.simpledriverlocator;
import java.io.IOException;
import java.io.InputStream;
import java.security.AccessController;
import java.security.PrivilegedExceptionAction;
import java.util.Dictionary;
import org.osgi.service.device.*;
import org.xml.sax.SAXException;

import java.net.*;
import javax.xml.parsers.*;
import java.util.*;
/**
 * SimpleDriverLocator contains the implementation of the 
 * DriverLocator class.  It is responsible for finding
 * driver IDs based on a given set of properties and it
 * returns an inputstream for a given driver ID.
 */

public class SimpleDriverLocator implements DriverLocator {

	SimpleDriverLocatorData data;
	
	/** 
	* In the constructor, we create the SimpleDriverLocatorData
	* object which will load the SimpleDriverLocator's data. 
	* 
	*/
	
	public SimpleDriverLocator(SAXParserFactory parserFactory)
	{
		data = new SimpleDriverLocatorData(parserFactory);
	}
	
	
	/**
	 * @see DriverLocator#findDrivers(Dictionary)
	 */
	public String[] findDrivers(Dictionary props) {
		return (data.findDrivers(props));
	}

	/**
	 * loadDriver creates an InputStream from a driver ID.  It
	 * uses the SimpleDriverLocatorData class to map the ID to the
	 * url.  
	 * @see DriverLocator#loadDriver(String)
	 */
	public InputStream loadDriver(String id) throws IOException {
		if(id == null)
		{
			throw (new IOException("SimpleDriverLocator loadDriver failed.  Driver id can not be null"));	
		}
		final String urlString = data.getURLFromID(id);
		try {
		  if(urlString != null)
		  {
		     return (InputStream)AccessController.doPrivileged(new PrivilegedExceptionAction() {
                        public java.lang.Object run() throws Exception {
                            
                            URL url = new URL(urlString);
		    				return(url.openStream());
                        }
             });
		    
		    
		  }
		} catch(Throwable t)
		{
			throw (new IOException("Unable to create inputstream for DriverID=" + id + "  Reason: " + t.getMessage()));
		}
		throw (new IOException("Unable to create inputstream for DriverID " + id));
	}

}

