/*
 * IBM Confidential
 *
 * OCO Source Materials
 *
 * 0000-000
 *
 * (C) Copyright IBM Corp. 2002.
 *
 * The source code for this program is not published or other-
 * wise divested of its trade secrets, irrespective of what has
 * been deposited with the U. S. Copyright Office.
 */


package com.ibm.osg.sample.simpledriverlocator;
import java.util.*;
import javax.xml.parsers.*;
/**
 * The SimpleDriverLocator class maintains the data structures 
 * needed to respesent the driver locator configuration information
 * found in the configuration file (driverlocator.properties).
 * 
 * These data structures are populated by the DataParser class.
 * 
 */


public class SimpleDriverLocatorData {
	
	// PropertyName -> PropertyValues 
	protected Vector propValuePairs;
	
	// DrierIDs -> URLs
	private Hashtable driverIDtoURL;
	
	public SimpleDriverLocatorData(SAXParserFactory parserFactory)
	{
		propValuePairs = new Vector(20);
		driverIDtoURL = new Hashtable(20);
		new DataParser(this,parserFactory);
	}

	protected PropertyValuePair addPropertyValue(String propName,String propValue)
	{
		PropertyValuePair valuePair = new PropertyValuePair(propName,propValue);
		propValuePairs.addElement(valuePair);
		return (valuePair);
		  
	}
	
	protected void addDrivertoPropValue(PropertyValuePair pair,String driverID, String url)
	{ 
		driverIDtoURL.put(driverID,url);
		pair.addDriverID(driverID);
	}
	
	protected String[] findDrivers(Dictionary props)
	{
		Enumeration e = props.keys();
		Vector driverIDs = new Vector(20);
		while(e.hasMoreElements())
		{
			
			//look at each set of properties and see if it is matched
			//to a property value pair.  If it is, add driverIDs
			//associated with property value pair to returned array 
			
			String propName = (String)e.nextElement();
			Object valObject = props.get(propName);
			if(valObject instanceof String)
			{
			  String propValue = (String)valObject;
			  PropertyValuePair testPair = new PropertyValuePair(propName.toUpperCase(),propValue.toUpperCase());
			  //indexOf uses ".equals".  The .equals method is overwritten
			  //in the PropertyValuePair object
			  int index = propValuePairs.indexOf(testPair);
			  if(index != -1)
			  {
				PropertyValuePair pair = (PropertyValuePair)propValuePairs.elementAt(index);
			    if(pair.driverIds != null)
			    {
				   Enumeration enum = (pair.driverIds).elements();
				   while(enum.hasMoreElements())
				   {
				     String driverID = (String)enum.nextElement();
				     driverIDs.add(driverID);
				   }
			    }
			  }
			}
		}
		if(driverIDs.isEmpty())
		{
			return(null);
		}
		else
		{
			String[] driverIDArray = new String[driverIDs.size()];
		    driverIDs.copyInto(driverIDArray);
		    return (driverIDArray);
		}	
	}
	
	
	//Used by SimpleDriverLocator class to map driver IDs to
	//urls.
	protected String getURLFromID(String id)
	{
		Enumeration e = driverIDtoURL.keys();
		while(e.hasMoreElements())
		{
			String key = (String)e.nextElement();
			
		}
		return (String)driverIDtoURL.get(id);
	}
}

