/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar;

import javax.servlet.ServletConfig;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.ibm.pvc.example.calendar.controller.CalendarController;
import com.ibm.pvc.example.calendar.controller.CalendarControllerFactory;
import com.ibm.pvc.example.calendar.model.SettingsDAO;
import com.ibm.pvc.example.calendar.view.ExceptionView;


/**
 * This is the CalendarServlet class.
 * 
 * The Calendar sample application follows the Model-View-Controller (MVC)
 * pattern with a Front Controller.  The CalendarServlet is the Front Controller.
 * As such, it is the entry point to all requests that need to be handled by other
 * controllers.  
 * 
 * The Calendar sample contains the following packages:
 * 
 * * com.ibm.pvc.example.calendar
 *   This package contains the CalendarServlet itself, along with the bundle
 *   activator (CalendarBundle) and other high level objects that cross MVC 
 *   boundaries, such as Constants and Exceptions.
 *   
 * * com.ibm.pvc.example.calendar.controller
 *   This package contains all the Controller classes used to handle the 
 *   mapping of user requests to the associated "business logic" to carry 
 *   out the request.  Based on the results of the business logic execution,
 *   the controller selects the appropriate View class to render the results 
 *   and pass control back to the end-user.  
 *   This package also contains a Factory (CalendarControllerFactory).  This 
 *   factory is used by the CalendarServlet to create the appropriate controller 
 *   class to invoke based on the user's request. 
 * 
 * * com.ibm.pvc.example.calendar.model 
 *   This package contains the classes for low-level business logic and 
 *   database access.  Access to backing stores are implemented based on
 *   the Data Access Object (DAO) pattern 
 * 
 * * com.ibm.pvc.example.calendar.model.command
 *   This package contains the classes for high-level business logic based
 *   on the Command Pattern.  These classes use the low-level model classes
 *   to build higher levels of abstractions based on typical user requests.
 *   The classes in this package are used by the controller classes to 
 *   implement the Command and Controller pattern.
 * 
 * * com.ibm.pvc.example.calendar.view
 *   This package contain the classes responsible for rendering the Calendar
 *   application's panels.  The view portion of the code is targeted toward
 *   a 1/4 VGA screen with only HTML 3.0.2 support.  
 * 
 * * com,ibm.pvc.example.command
 *   This package defines the Command interface, which is not specific to the
 *   Calendar application.
 * 
 */
public class CalendarServlet extends HttpServlet {

	CalendarControllerFactory controllerFactory = null;

	public static final java.util.ResourceBundle Resource =
		java.util.ResourceBundle.getBundle(
			"com.ibm.pvc.example.calendar.view.Resources");

	/** Servlet URI */
	public static final String SERVLET_URI = "/Calendar";

	/** Servlet images URI suffix */
	public static final String IMAGES_URI = "/PIMImages";

	/** Servlet images URI suffix */
	public static final String HELP_URI = "/PIMHelp";

	/**
	 * @see javax.servlet.http.HttpServlet#doGet(HttpServletRequest, HttpServletResponse)
	 */
	protected void doGet(
		HttpServletRequest request,
		HttpServletResponse response)
		throws ServletException, java.io.IOException {
		processRequest(request, response);
	}
	/**
	 * @see javax.servlet.http.HttpServlet#doPost(HttpServletRequest, HttpServletResponse)
	 */
	protected void doPost(
		HttpServletRequest request,
		HttpServletResponse response)
		throws ServletException, java.io.IOException {
		processRequest(request, response);
	}

	/**
	 * @see javax.servlet.Servlet#init(ServletConfig)
	 */
	public void init(ServletConfig config) {
		controllerFactory = new CalendarControllerFactory();
	}
	/**
	 * Method processRequest.
	 * @param request
	 * @param response
	 * @throws ServletException
	 * @throws IOException
	 */
	protected void processRequest(
		HttpServletRequest request,
		HttpServletResponse response)
		throws ServletException, java.io.IOException {
		try {
			String action =
				CalendarServletHelper.getParameterAsString(
					request,
					CalendarConstants.PARM_ACTION,
					SettingsDAO.getAppSettings().getDefaultAction());

			CalendarController controller =
				controllerFactory.getControllerForAction(action);

			if (controller == null) {
				throw new InvalidServletParameterValueException(
					CalendarConstants.PARM_ACTION,
					action);
			}

			controller.processRequest(request, response);

		} catch (Exception ex) {
			ExceptionView view = new ExceptionView(ex);
			view.outputView(request, response);
		} catch (Error error) {
			ExceptionView view =
				new ExceptionView(new Exception(error.toString()));
			view.outputView(request, response);
		}
	}
}
