/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar.controller;

import javax.servlet.ServletException;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpSession;

import com.ibm.pvc.example.calendar.CalendarConstants;
import com.ibm.pvc.example.calendar.CalendarServletException;
import com.ibm.pvc.example.calendar.CalendarServletHelper;
import com.ibm.pvc.example.calendar.InvalidServletParameterValueException;
import com.ibm.pvc.example.calendar.NoCurrentViewAvailableException;
import com.ibm.pvc.example.calendar.view.CalendarAppView;

/**
 * This is the FramesetController class.
 *
 * The CalendarServlet example application is designed to render both as
 * a frameset-based and a non-frameset-based UI.  This class is responsible
 * for getting the proper frameset/frame view pieces to be rendered for the
 * current view. 
 * 
 */
public class FramesetController extends CalendarController {
	public static final String ACTION = "Frameset";
	
	public static final String PARM_FRAMESET_COMPONENT = "FSC";
	public static final String FSC_VIEW_FS             = "ViewFS";
	public static final String FSC_VIEW_HEADING        = "ViewHeading";
	public static final String FSC_VIEW_CONTENT        = "ViewContent";
	public static final String FSC_VIEW_MENU           = "ViewMenu";

	/**
	 * @see java.lang.Object#Object()
	 */
	public FramesetController() {
		super();
	}
	public static final String buildUrl(String framesetComponent) {
		return CalendarServletHelper.buildServletActionUrl(FramesetController.ACTION)
			+ CalendarServletHelper.buildServletUrlParmAddition(
				FramesetController.PARM_FRAMESET_COMPONENT,
				framesetComponent);
	}

	/**
	 * @see com.ibm.pvc.example.calendar.controller.CalendarController#processRequest(HttpServletRequest, HttpServletResponse)
	 */
	public void processRequest(
		javax.servlet.http.HttpServletRequest request,
		javax.servlet.http.HttpServletResponse response)
		throws ServletException, java.io.IOException, CalendarServletException {
		HttpSession session = request.getSession();
		CalendarAppView currentView =
			(CalendarAppView) session.getValue(CalendarConstants.ATTR_CURRENT_VIEW);
		if (currentView == null) {
			throw new NoCurrentViewAvailableException();
		}
		ServletOutputStream out = response.getOutputStream();
		response.setContentType("text/html");
		response.setStatus(response.SC_OK);
		response.setDateHeader("Expires", 0);
		
		String framesetComponent =
			CalendarServletHelper.getParameterAsString(
				request,
				FramesetController.PARM_FRAMESET_COMPONENT);
		if (framesetComponent.equals(FramesetController.FSC_VIEW_CONTENT)) {
			currentView.outputViewContentFrame(out);
		}
		else if (framesetComponent.equals(FramesetController.FSC_VIEW_FS)) {
			currentView.outputViewFrameset(out);
		}
		else if (framesetComponent.equals(FramesetController.FSC_VIEW_HEADING)) {
			currentView.outputViewHeadingFrame(out);
		}
		else if (framesetComponent.equals(FramesetController.FSC_VIEW_MENU)) {
			currentView.outputViewMenuFrame(out);
		}
		else {
			throw new InvalidServletParameterValueException(
				FramesetController.PARM_FRAMESET_COMPONENT,
				framesetComponent);
		}
	}
}