	
/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar.controller;

import javax.servlet.ServletException;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpSession;

import com.ibm.pvc.example.calendar.CalendarConstants;
import com.ibm.pvc.example.calendar.CalendarServletException;
import com.ibm.pvc.example.calendar.CalendarServletHelper;
import com.ibm.pvc.example.calendar.InvalidServletParameterValueException;
import com.ibm.pvc.example.calendar.NoCurrentViewAvailableException;
import com.ibm.pvc.example.calendar.view.CalendarAppView;

/**
 * This is the HelpController class.
 *
 * This clas is responsible for getting context sensitive help to be rendered
 * for the current view.
 * 
 */
public class HelpController extends CalendarController {
	public static final String ACTION = "Help";
	
	public static final String PARM_HELP_COMPONENT = "HC";
	
	public static final String HC_VIEW_HEADING = "ViewHeading";
	public static final String HC_VIEW_CONTENT = "ViewContent";
	public static final String HC_VIEW_MENU    = "ViewMenu";
	public static final String HC_VIEW_TOP     = "HelpTop";
	public static final String HC_VIEW_RETURN  = "HelpReturn";

	/**
	 * @see java.lang.Object#Object()
	 */
	public HelpController() {
		super();
	}
	public static final String buildUrl(String helpComponent) {
		return CalendarServletHelper.buildServletActionUrl(HelpController.ACTION)
			+ CalendarServletHelper.buildServletUrlParmAddition(
				HelpController.PARM_HELP_COMPONENT,
				helpComponent);
	}

	/**
	 * @see com.ibm.pvc.example.calendar.controller.CalendarController#processRequest(HttpServletRequest, HttpServletResponse)
	 */
	public void processRequest(
		javax.servlet.http.HttpServletRequest request,
		javax.servlet.http.HttpServletResponse response)
		throws ServletException, java.io.IOException, CalendarServletException {
		HttpSession session = request.getSession();
		CalendarAppView currentView =
			(CalendarAppView) session.getValue(CalendarConstants.ATTR_CURRENT_VIEW);
		if (currentView == null) {
			throw new NoCurrentViewAvailableException();
		}
		ServletOutputStream out = response.getOutputStream();
		String helpComponent =
			CalendarServletHelper.getParameterAsString(
				request,
				HelpController.PARM_HELP_COMPONENT);

		if (helpComponent.equals(HelpController.HC_VIEW_TOP)) {
			currentView.outputHelpViewFrameset(out);
		}	
		else if (helpComponent.equals(HelpController.HC_VIEW_MENU)) {
			currentView.outputHelpViewMenuFrame(out);
		}	
		else if (helpComponent.equals(HelpController.HC_VIEW_RETURN)) {
			currentView.outputView(request, response);
		}			

		else {
			throw new InvalidServletParameterValueException(
				HelpController.PARM_HELP_COMPONENT,
				helpComponent);
		}
	}
}