/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar.controller;

import java.util.Calendar;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.ibm.pvc.example.calendar.CalendarConstants;
import com.ibm.pvc.example.calendar.CalendarServletException;
import com.ibm.pvc.example.calendar.CalendarServletHelper;
import com.ibm.pvc.example.calendar.model.command.MonthInfoCommand;
import com.ibm.pvc.example.calendar.view.MonthInfoView;
import com.ibm.pvc.example.command.CommandException;

/**
 * This is the MonthInfoController class.
 *
 * This controller class is responsible for handling the retrieval of the
 * events for a specific month.  These events are then passed to the Month Info
 * View and that view is rendered.
 * 
 */
public class MonthInfoController extends CalendarController {
	public static final String ACTION = "MonthInfo";

	/**
	 * @see java.lang.Object#Object()
	 */
	public MonthInfoController() {
		super();
	}
	/**
	 * Method buildUrl.
	 * @return String
	 */
	public static final String buildUrl() {
		return CalendarServletHelper.buildServletActionUrl(MonthInfoController.ACTION);
	}
	/**
	 * Method buildUrl.
	 * @param currentDate
	 * @return String
	 */
	public static final String buildUrl(java.util.Calendar currentDate) {
		return CalendarServletHelper.buildServletActionUrl(MonthInfoController.ACTION)
			+ CalendarServletHelper.buildServletUrlParmAddition(
				CalendarConstants.PARM_TIMESTAMP,
				currentDate);
	}

	/**
	 * @see com.ibm.pvc.example.calendar.controller.CalendarController#processRequest(HttpServletRequest, HttpServletResponse)
	 */
	public void processRequest(
		HttpServletRequest request,
		HttpServletResponse response)
		throws
			ServletException,
			java.io.IOException,
			CommandException,
			CalendarServletException {
		Calendar currentDate =
			CalendarServletHelper.getAppCalendarInstanceForTimestampParm(request);

		MonthInfoCommand command = new MonthInfoCommand();
		command.setCurrentDate(currentDate);

		command.execute();

		MonthInfoView view =
			new MonthInfoView(
				CalendarServletHelper.getAppCalendarInstanceForTimestampParm(request),
				command.getDayInfos());

		view.outputView(request, response);
	}
}