/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar.controller;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.ibm.pvc.example.calendar.CalendarServletException;
import com.ibm.pvc.example.calendar.CalendarServletHelper;
import com.ibm.pvc.example.calendar.model.MutableSettings;
import com.ibm.pvc.example.calendar.model.Settings;
import com.ibm.pvc.example.calendar.model.SettingsDAO;
import com.ibm.pvc.example.calendar.view.SettingsView;
import com.ibm.pvc.example.command.CommandException;

/**
 * This is the SettingsController class.
 * 
 * This controller class is responsible for retreiving the settings data 
 * and creating a view to display the update settings form to the user.
 * When the user has entered the updated data, this class will execute the 
 * appropriated business logic to update these settings based on the user's
 * input and then redisplay the update settings form.
 *     
 */
public class SettingsController extends CalendarController {
	public static final String ACTION = "Settings";

	/**
	 * @see java.lang.Object#Object()
	 */
	public SettingsController() {
		super();
	}
	/**
	 * Method buildUrl.
	 * @return String
	 */
	public static final String buildUrl() {
		return CalendarServletHelper.buildServletActionUrl(SettingsController.ACTION);
	}

	/**
	 * @see com.ibm.pvc.example.calendar.controller.CalendarController#processRequest(HttpServletRequest, HttpServletResponse)
	 */
	public void processRequest(
		HttpServletRequest request,
		HttpServletResponse response)
		throws
			ServletException,
			java.io.IOException,
			CommandException,
			CalendarServletException {
		MutableSettings mSettings = SettingsDAO.getMutableSettings();
		String submit = request.getParameter("SUBMIT");

		// submit will be null if coming from a link, it will be present if user clicked button
		if (submit == null) {
			SettingsView view = new SettingsView((Settings) mSettings);
			view.outputView(request, response);
		}
		else {
			boolean showGrid =
				(
					CalendarServletHelper.getParameterAsString(
						request,
						"DailyGridDisplay",
						"No")).equals(
					"Yes");
			int gridFirstHour =
				CalendarServletHelper.getParameterAsInt(request, "FirstHour");
			String gridFirstHourAmPm =
				CalendarServletHelper.getParameterAsString(request, "FirstAmPm");
			int gridLastHour = CalendarServletHelper.getParameterAsInt(request, "LastHour");
			String gridLastHourAmPm =
				CalendarServletHelper.getParameterAsString(request, "LastAmPm");
			String defaultAction =
				CalendarServletHelper.getParameterAsString(request, "DefaultView");
			String titlesBgColor =
				CalendarServletHelper.getParameterAsString(request, "BGColor");
			String titlesFgColor =
				CalendarServletHelper.getParameterAsString(request, "FGColor");								
			boolean overflowSupported =
				(
					CalendarServletHelper.getParameterAsString(
						request,
						"OverflowSupported",
						"No")).equals(
					"Yes");				
			try {
				gridFirstHour += (gridFirstHourAmPm.equals("PM") ? 12 : 0);	
				gridLastHour += (gridLastHourAmPm.equals("PM") ? 12 : 0);
				if (gridLastHour < gridFirstHour) { // User error: set to valid value
					gridLastHour = gridFirstHour;
				}						
				mSettings.setShowDailyTimeGrid(showGrid);
				mSettings.setDailyTimeGridFirstHour(gridFirstHour);
				mSettings.setDailyTimeGridLastHour(gridLastHour);
				mSettings.setDefaultAction(defaultAction);
				mSettings.setTitlesBgColor(titlesBgColor);
				mSettings.setTitlesFgColor(titlesFgColor);	
				mSettings.setOverflowSupported(overflowSupported);								
				SettingsDAO.store(mSettings);
				SettingsView view = new SettingsView((Settings) mSettings);
				view.outputView(request, response);
			}
			catch (Exception exception) {
				SettingsView view = new SettingsView((Settings) mSettings);
				view.outputView(request, response);
			}
		}
	}
}