/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar.controller;

import java.util.Calendar;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import com.ibm.pvc.example.calendar.CalendarConstants;
import com.ibm.pvc.example.calendar.CalendarServletException;
import com.ibm.pvc.example.calendar.CalendarServletHelper;
import com.ibm.pvc.example.calendar.NoCurrentViewAvailableException;
import com.ibm.pvc.example.calendar.model.Event;
import com.ibm.pvc.example.calendar.model.EventCategories;
import com.ibm.pvc.example.calendar.model.command.DayInfoCommand;
import com.ibm.pvc.example.calendar.model.command.GetEventCommand;
import com.ibm.pvc.example.calendar.model.command.UpdateEventCommand;
import com.ibm.pvc.example.calendar.view.CalendarAppView;
import com.ibm.pvc.example.calendar.view.DayInfoView;
import com.ibm.pvc.example.calendar.view.UpdateEventView;
import com.ibm.pvc.example.command.CommandException;

/**
 * This is the UpdateEventController class.
 * 
 * This controller class is responsible for retreiving the data for a given
 * event and creating a view to display the Update event form to the user.
 * When the user has entered the updated data, this class will execute the 
 * appropriated business logic to update the event based on the user's input
 * in the Calendar event database.  When the event has been successfully updated, 
 * the Daily view for the date of the updated event is rendered.
 *    
 */
public class UpdateEventController extends CalendarController {
	public static final String ACTION = "UpdateEvent";

	/**
	 * @see java.lang.Object#Object()
	 */
	public UpdateEventController() {
		super();
	}
	/**
	 * Method buildUrl.
	 * @param event
	 * @return String
	 */
	public static final String buildUrl(Event event) {
		return CalendarServletHelper.buildServletActionUrl(
			UpdateEventController.ACTION)
			+ CalendarServletHelper.buildServletUrlParmAddition(
				CalendarConstants.PARM_LUID,
				event.getLuid());
	}

	/**
	 * @see com.ibm.pvc.example.calendar.controller.CalendarController#processRequest(HttpServletRequest, HttpServletResponse)
	 */
	public void processRequest(
		HttpServletRequest request,
		HttpServletResponse response)
		throws
			ServletException,
			java.io.IOException,
			CommandException,
			CalendarServletException {

		String submit = request.getParameter("SUBMIT");
		String cancel = request.getParameter("CANCEL");		

		if (submit != null) {
			Event event = null;
			try {
				String luid = request.getParameter(CalendarConstants.PARM_LUID),
					summary = request.getParameter(CalendarConstants.PARM_SUMMARY),
					details = request.getParameter(CalendarConstants.PARM_DETAILS),
					eventType = request.getParameter("EventType"),
					month = request.getParameter("Month"),
					day = request.getParameter("Day"),
					year = request.getParameter("Year"),
					startHour = request.getParameter("StartHour"),
					startMinute = request.getParameter("StartMinute"),
					startAmPm = request.getParameter("StartAmPm"),
					duration = request.getParameter("Duration");
				String[] categoriesArray =
					request.getParameterValues(CalendarConstants.PARM_CATEGORIES);
				EventCategories categories = new EventCategories(categoriesArray);

				Calendar evtStart = CalendarServletHelper.getAppCalendarInstance();
				Calendar evtEnd = null;

				evtStart.set(Calendar.YEAR, (new Integer(year)).intValue());
				evtStart.set(Calendar.MONTH, (new Integer(month)).intValue());
				evtStart.set(Calendar.DAY_OF_MONTH, (new Integer(day)).intValue());

				if (eventType.equals("TimedEvent")) {
					evtStart.set(Calendar.HOUR, (new Integer(startHour)).intValue());
					evtStart.set(Calendar.MINUTE, (new Integer(startMinute)).intValue());
					evtStart.set(Calendar.AM_PM, (startAmPm.equals("AM") ? Calendar.AM : Calendar.PM));
					evtEnd = (Calendar) evtStart.clone();
					evtEnd.add(Calendar.MINUTE, (new Integer(duration)).intValue());
				}
				event =
					new Event(new Integer(luid), summary, details, evtStart, evtEnd, categories);

				UpdateEventCommand command = new UpdateEventCommand();

				command.setEvent(event);

				command.execute();

				DayInfoCommand dayInfoCommand = new DayInfoCommand();
				dayInfoCommand.setCurrentDate(evtStart);

				dayInfoCommand.execute();

				DayInfoView dayInfoView =
					new DayInfoView(evtStart, dayInfoCommand.getDayInfo());

				dayInfoView.outputView(request, response);
			}
			catch (Exception ex) {
				// The current panel is designed to prevent user error on input.
				// There is no error specific to the data to report.
				// This exception will be rethrown as a CalendarServletException.
				throw new CalendarServletException(ex.toString());
			}
		}
		else if (cancel != null) {
			HttpSession session = request.getSession();
			
			CalendarAppView returnToView =
				(CalendarAppView) session.getValue(CalendarConstants.ATTR_RETURN_TO_VIEW);
			session.removeValue(CalendarConstants.ATTR_RETURN_TO_VIEW);
					
			returnToView.outputView(request, response);
		}	
		else  { // if (submit == null) 
			HttpSession session = request.getSession();
			CalendarAppView currentView =
				(CalendarAppView) session.getValue(CalendarConstants.ATTR_CURRENT_VIEW);

			session.putValue(CalendarConstants.ATTR_RETURN_TO_VIEW,  currentView);
			
			if (currentView == null) {
				throw new NoCurrentViewAvailableException();
			}
				
			String luid = request.getParameter(CalendarConstants.PARM_LUID);

			GetEventCommand command = new GetEventCommand();

			command.setLuid(new Integer(luid));

			command.execute();

			UpdateEventView view = new UpdateEventView(command.getEvent());

			view.outputView(request, response);
		}			

	}
}