/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar.model;

import java.util.ArrayList;
import java.util.Calendar;

/**
 * This is the DayInfo class.
 * 
 * This class is a convenience class for storing and querying information 
 * about the events for a specific date.
 */
public class DayInfo {
	private Calendar currentDate;
	private ArrayList allDayEventsList = new ArrayList();
	private ArrayList timedEventsList = new ArrayList();

	/**
	 * Method DayInfo.
	 * @param currentDate
	 */
	public DayInfo(Calendar currentDate) {
		super();
		this.currentDate = (Calendar) currentDate.clone();
	}

	/**
	 * Method addEvent.
	 * @param event
	 */
	public void addEvent(Event event) {
		// For efficiency, there is no check to validate that the event is from the correct date.
		if (event.isAllDayEvent()) {
			allDayEventsList.add(event);
		}
		else {
			timedEventsList.add(event);
		}
	}

	/**
	 * Method getAllDayEvents.
	 * @return Event[]
	 */
	public com.ibm.pvc.example.calendar.model.Event[] getAllDayEvents() {
		Event[] events = new Event[allDayEventsList.size()];
		events = (Event[]) allDayEventsList.toArray(events);
		return events;
	}

	/**
	 * Method getChronologicalTimedEvents.
	 * @return Event[]
	 */
	public com.ibm.pvc.example.calendar.model.Event[] 
		getChronologicalTimedEvents() {

		Event[] events = new Event[timedEventsList.size()];

		events = (Event[]) timedEventsList.toArray(events);

		Event event1, event2;

		for (int i = 0; i < events.length - 1; i++)
			for (int j = i + 1; j < events.length; j++) {
				event1 = events[i];
				event2 = events[j];
				if ((event1.getEvtStart().after(event2.getEvtStart()))
					|| ((event1.getEvtStart().equals(event2.getEvtStart()))
						&& (event1.getEvtEnd()).after(event2.getEvtEnd()))) {
					events[i] = event2;
					events[j] = event1;
				}
			}

		return events;
	}

	/**
	 * Method isConflictingTimedEvent.
	 * @param timedEvent
	 * @return boolean
	 */
	public boolean isConflictingTimedEvent(Event timedEvent) {

		boolean conflicting = false;

		int timedEventsCount = timedEventsList.size();

		for (int i = 0;((i < timedEventsCount) && (conflicting == false)); i++) {
			conflicting = timedEvent.conflictsWith((Event) timedEventsList.get(i));
		}

		return conflicting;
	}

	/**
	 * Method getCurrentDate.
	 * @return Calendar
	 */
	public java.util.Calendar getCurrentDate() {
		return currentDate;
	}
	/**
	 * Method containsAllDayEvent.
	 * @return boolean
	 */
	public boolean containsAllDayEvent() {
		return (allDayEventsList.size() > 0);
	}
	/**
	 * Method containsEventInAm.
	 * @return boolean
	 */
	public boolean containsEventInAm() {
		boolean eventFound = false;

		Calendar noonOnCurrentDate = (Calendar) currentDate.clone();
		noonOnCurrentDate.set(Calendar.HOUR_OF_DAY, 12);
		noonOnCurrentDate.set(Calendar.MINUTE, 0);
		noonOnCurrentDate.set(Calendar.SECOND, 0);
		noonOnCurrentDate.set(Calendar.MILLISECOND, 0);

		Event timedEvent = null;
		;

		int timedEventsCount = timedEventsList.size();

		for (int i = 0;((i < timedEventsCount) && (eventFound == false)); i++) {
			timedEvent = (Event) timedEventsList.get(i);

			if (timedEvent.getEvtStart().before(noonOnCurrentDate)) {
				eventFound = true;
			}
		}
		return (eventFound);
	}
	/**
	 * Method containsEventInPm.
	 * @return boolean
	 */
	public boolean containsEventInPm() {
		boolean eventFound = false;

		Calendar noonOnCurrentDate = (Calendar) currentDate.clone();
		noonOnCurrentDate.set(Calendar.HOUR_OF_DAY, 12);
		noonOnCurrentDate.set(Calendar.MINUTE, 0);
		noonOnCurrentDate.set(Calendar.SECOND, 0);
		noonOnCurrentDate.set(Calendar.MILLISECOND, 0);

		Event timedEvent = null;
		;

		int timedEventsCount = timedEventsList.size();

		for (int i = 0;((i < timedEventsCount) && (eventFound == false)); i++) {
			timedEvent = (Event) timedEventsList.get(i);

			if (!timedEvent.getEvtEnd().before(noonOnCurrentDate)) {
				eventFound = true;
			}
		}
		return (eventFound);
	}
}