/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar.model;

import java.util.Calendar;

/**
 * This is the Event class.
 * 
 * This class contains all the information about a specific calendar event.
 */
public class Event {
	protected Integer luid;
	protected String summary;
	protected Calendar evtStart;
	protected Calendar evtEnd;
	protected String details;
	protected EventCategories categories;

	/**
	 * Method Event.
	 * @param luid
	 * @param summary
	 * @param details
	 * @param evtStart
	 * @param evtEnd
	 * @param categories
	 */
	public Event(
		Integer luid,
		String summary,
		String details,
		Calendar evtStart,
		Calendar evtEnd,
		EventCategories categories) {
		super();
		this.luid = luid;
		this.summary = summary;
		this.details = details;
		this.evtStart = evtStart;
		this.evtEnd = evtEnd;
		this.categories = categories;
	}

	/**
	 * Method getCategories.
	 * @return EventCategories
	 */
	public EventCategories getCategories() {
		return this.categories;
	}

	/**
	 * Method getDetails.
	 * @return String
	 */
	public java.lang.String getDetails() {
		return this.details;
	}

	/**
	 * Method getDurationInMinutes.
	 * @return long
	 */
	public long getDurationInMinutes() {
		return (
			(evtEnd == null)
				? 0
				: (evtEnd.getTime().getTime() - evtStart.getTime().getTime()) / (60 * 1000));
	}

	/**
	 * Method getEvtEnd.
	 * @return Calendar
	 */
	public java.util.Calendar getEvtEnd() {
		return this.evtEnd;
	}

	/**
	 * Method getEvtStart.
	 * @return Calendar
	 */
	public java.util.Calendar getEvtStart() {
		return this.evtStart;
	}

	/**
	 * Method getLuid.
	 * @return Integer
	 */
	public java.lang.Integer getLuid() {
		return this.luid;
	}

	/**
	 * Method getSummary.
	 * @return String
	 */
	public java.lang.String getSummary() {
		return this.summary;
	}

	/**
	 * Method isAllDayEvent.
	 * @return boolean
	 */
	public boolean isAllDayEvent() {
		return (this.evtEnd == null);
	}

	/**
	 * Method conflictsWith.
	 * @param event2
	 * @return boolean
	 */
	public boolean conflictsWith(Event event2) {
		boolean conflicts = false;
		Calendar event2Start = event2.getEvtStart();
		Calendar event2End = event2.getEvtEnd();

		// Can't conflict with self	
		if (this.equals(event2)) {
			conflicts = false;
		}
		// All day events don't conflict, if either event's end is null, no conflict		
		else if ((this.evtEnd == null) || (event2.getEvtEnd() == null)) {
			conflicts = false;
		}
		// if one event ends before the other starts, there is no conflict
		else if ((this.evtEnd.before(event2Start)) || (event2End.before(this.evtStart))) {
			conflicts = false;
		}
		// if one event ends at the other's start, there is no conflict
		else if ((this.evtEnd.equals(event2Start)) || (event2End.equals(this.evtStart))) {
			conflicts = false;
		}		
		// if one event starts between the start and end of the other, there is a conflict	
		else if (
			((!this.evtStart.before(event2Start)) && (this.evtStart.before(event2End)))
				|| ((!event2Start.before(this.evtStart)) && (event2Start.before(this.evtEnd)))) {
			conflicts = true;
		}

		return (conflicts);
	}

	/**
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		return "Event[luid:"
			+ getLuid()
			+ "; summary: "
			+ getSummary()
			+ "; details: "
			+ getDetails()
			+ "; evtStart: "
			+ getEvtStart().getTime()
			+ "; evtEnd: "
			+ (isAllDayEvent() ? "AllDayEvent" : getEvtEnd().getTime().toString())
			+ "; categories: "
			+ getCategories()
			+ "]";
	}
}