/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar.model;


/**
 * This is the EventCategories class.
 * 
 * Calendar events can be declared to be in several categories.  This
 * class provides data type support for multi-valued event categories.
 */
public class EventCategories {
	private boolean appointment = false;
	private boolean business = false;
	private boolean education = false;
	private boolean holiday = false;
	private boolean meeting = false;
	private boolean miscellaneous = false;
	private boolean personal = false;
	private boolean phoneCall = false;
	private boolean sickDay = false;
	private boolean specialOccasion = false;
	private boolean travel = false;
	private boolean vacation = false;
	private boolean other = false;

	public static final String APPOINTMENT = "APPOINTMENT";
	public static final String BUSINESS = "BUSINESS";
	public static final String EDUCATION = "EDUCATION";
	public static final String HOLIDAY = "HOLIDAY";
	public static final String MEETING = "MEETING";
	public static final String MISCELLANEOUS = "MISCELLANEOUS";
	public static final String PERSONAL = "PERSONAL";
	public static final String PHONE_CALL = "PHONECALL";
	public static final String SICK_DAY = "SICKDAY";
	public static final String SPECIAL_OCCASION = "SPECIAL";
	public static final String TRAVEL = "TRAVEL";
	public static final String VACATION = "VACATION";
	public static final String OTHER = "OTHER";

	/**
	 * @see java.lang.Object#Object()
	 */
	public EventCategories() {
		super();
	}

	/**
	 * Method EventCategories.
	 * @param iCalCategories
	 */
	public EventCategories(String iCalCategories) {
		super();
		this.appointment = (iCalCategories.indexOf(EventCategories.APPOINTMENT) > -1);
		this.business = (iCalCategories.indexOf(EventCategories.BUSINESS) > -1);
		this.education = (iCalCategories.indexOf(EventCategories.EDUCATION) > -1);
		this.holiday = (iCalCategories.indexOf(EventCategories.HOLIDAY) > -1);
		this.meeting = (iCalCategories.indexOf(EventCategories.MEETING) > -1);
		this.miscellaneous =
			(iCalCategories.indexOf(EventCategories.MISCELLANEOUS) > -1);
		this.personal = (iCalCategories.indexOf(EventCategories.PERSONAL) > -1);
		this.phoneCall = (iCalCategories.indexOf(EventCategories.PHONE_CALL) > -1);
		this.sickDay = (iCalCategories.indexOf(EventCategories.SICK_DAY) > -1);
		this.specialOccasion =
			(iCalCategories.indexOf(EventCategories.SPECIAL_OCCASION) > -1);
		this.travel = (iCalCategories.indexOf(EventCategories.TRAVEL) > -1);
		this.vacation = (iCalCategories.indexOf(EventCategories.VACATION) > -1);
		this.other = (iCalCategories.indexOf(EventCategories.OTHER) > -1);
	}

	/**
	 * Method EventCategories.
	 * @param categoriesArray
	 */
	public EventCategories(String[] categoriesArray) {
		super();
		for (int i = 0; i < categoriesArray.length; i++) {
			setCategoryFromString(categoriesArray[i]);
		}
	}

	/**
	 * Method setCategoryFromString.
	 * @param category
	 */
	public void setCategoryFromString(String category) {
		if (category.equals(EventCategories.APPOINTMENT))
			this.appointment = true;
		else if (category.equals(EventCategories.BUSINESS))
			this.business = true;
		else if (category.equals(EventCategories.EDUCATION))
			this.education = true;
		else if (category.equals(EventCategories.MEETING))
			this.meeting = true;
		else if (category.equals(EventCategories.MISCELLANEOUS))
			this.miscellaneous = true;
		else if (category.equals(EventCategories.PERSONAL))
			this.personal = true;
		else if (category.equals(EventCategories.PHONE_CALL))
			this.phoneCall = true;
		else if (category.equals(EventCategories.SICK_DAY))
			this.sickDay = true;
		else if (category.equals(EventCategories.SPECIAL_OCCASION))
			this.specialOccasion = true;
		else if (category.equals(EventCategories.TRAVEL))
			this.travel = true;
		else if (category.equals(EventCategories.VACATION))
			this.vacation = true;
		else if (category.equals(EventCategories.OTHER))
			this.other = true;
		else
			this.other = true;
	}

	/**
	 * Method asString.
	 * @return String
	 */
	public String asString() {
		String returnValue = "";

		returnValue += (this.appointment ? EventCategories.APPOINTMENT + ", " : "");
		returnValue += (this.business ? EventCategories.BUSINESS + ", " : "");
		returnValue += (this.education ? EventCategories.EDUCATION + ", " : "");
		returnValue += (this.holiday ? EventCategories.HOLIDAY + ", " : "");
		returnValue += (this.meeting ? EventCategories.MEETING + ", " : "");
		returnValue += (this.miscellaneous ? EventCategories.MISCELLANEOUS + ", " : "");
		returnValue += (this.personal ? EventCategories.PERSONAL + ", " : "");
		returnValue += (this.phoneCall ? EventCategories.PHONE_CALL + ", " : "");
		returnValue += (this.sickDay ? EventCategories.SICK_DAY + ", " : "");
		returnValue
			+= (this.specialOccasion ? EventCategories.SPECIAL_OCCASION + ", " : "");
		returnValue += (this.travel ? EventCategories.TRAVEL + ", " : "");
		returnValue += (this.vacation ? EventCategories.VACATION + ", " : "");
		returnValue += (this.other ? EventCategories.OTHER + ", " : "");

		// remove trailing ", " if present
		if (returnValue.length() > 0) {
			returnValue = returnValue.substring(0, returnValue.length() - 2);
		}

		return returnValue;
	}

	/**
	 * Method isAppointment.
	 * @return boolean
	 */
	public final boolean isAppointment() {
		return appointment;
	}

	/**
	 * Method isBusiness.
	 * @return boolean
	 */
	public final boolean isBusiness() {
		return business;
	}

	/**
	 * Method isPhoneCall.
	 * @return boolean
	 */
	public final boolean isPhoneCall() {
		return phoneCall;
	}

	/**
	 * Method isSickDay.
	 * @return boolean
	 */
	public final boolean isSickDay() {
		return sickDay;
	}

	/**
	 * Method isEducation.
	 * @return boolean
	 */
	public final boolean isEducation() {
		return education;
	}

	/**
	 * Method isHoliday.
	 * @return boolean
	 */
	public final boolean isHoliday() {
		return holiday;
	}

	/**
	 * Method isMeeting.
	 * @return boolean
	 */
	public final boolean isMeeting() {
		return meeting;
	}

	/**
	 * Method isMiscellaneous.
	 * @return boolean
	 */
	public final boolean isMiscellaneous() {
		return miscellaneous;
	}

	/**
	 * Method isSpecialOccasion.
	 * @return boolean
	 */
	public final boolean isSpecialOccasion() {
		return specialOccasion;
	}

	/**
	 * Method isOther.
	 * @return boolean
	 */
	public final boolean isOther() {
		return other;
	}

	/**
	 * Method isPersonal.
	 * @return boolean
	 */
	public final boolean isPersonal() {
		return personal;
	}

	/**
	 * Method isTravel.
	 * @return boolean
	 */
	public final boolean isTravel() {
		return travel;
	}

	/**
	 * Method isVacation.
	 * @return boolean
	 */
	public final boolean isVacation() {
		return vacation;
	}

	/**
	 * Method setAppointment.
	 * @param newAppointment
	 */
	public final void setAppointment(boolean newAppointment) {
		appointment = newAppointment;
	}

	/**
	 * Method setBusiness.
	 * @param newBusiness
	 */
	public final void setBusiness(boolean newBusiness) {
		business = newBusiness;
	}

	/**
	 * Method setPhoneCall.
	 * @param newCall
	 */
	public final void setPhoneCall(boolean newCall) {
		phoneCall = newCall;
	}

	/**
	 * Method setSickDay.
	 * @param newDay
	 */
	public final void setSickDay(boolean newDay) {
		sickDay = newDay;
	}

	/**
	 * Method setEducation.
	 * @param newEducation
	 */
	public final void setEducation(boolean newEducation) {
		education = newEducation;
	}

	/**
	 * Method setHoliday.
	 * @param newHoliday
	 */
	public final void setHoliday(boolean newHoliday) {
		holiday = newHoliday;
	}

	/**
	 * Method setMeeting.
	 * @param newMeeting
	 */
	public final void setMeeting(boolean newMeeting) {
		meeting = newMeeting;
	}

	/**
	 * Method setMiscelleneous.
	 * @param newMiscellaneous
	 */
	public final void setMiscelleneous(boolean newMiscellaneous) {
		miscellaneous = newMiscellaneous;
	}

	/**
	 * Method setSpecialOccasion.
	 * @param newOccasion
	 */
	public final void setSpecialOccasion(boolean newOccasion) {
		specialOccasion = newOccasion;
	}

	/**
	 * Method setOther.
	 * @param newOther
	 */
	public final void setOther(boolean newOther) {
		other = newOther;
	}

	/**
	 * Method setPersonal.
	 * @param newPersonal
	 */
	public final void setPersonal(boolean newPersonal) {
		personal = newPersonal;
	}

	/**
	 * Method setTravel.
	 * @param newTravel
	 */
	public final void setTravel(boolean newTravel) {
		travel = newTravel;
	}

	/**
	 * Method setVacation.
	 * @param newVacation
	 */
	public final void setVacation(boolean newVacation) {
		vacation = newVacation;
	}

	/**
	 * @see java.lang.Object#toString()
	 */
	public final String toString() {
		return "EventCategories[" + asString() + "]";
	}
}