/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar.model.command;

import java.sql.Connection;
import java.sql.SQLException;
import java.sql.Statement;

import com.ibm.pvc.example.calendar.model.DbHelper;
import com.ibm.pvc.example.calendar.model.EventDb;
import com.ibm.pvc.example.calendar.model.EventDbHelper;
import com.ibm.pvc.example.command.Command;
import com.ibm.pvc.example.command.CommandException;
import com.ibm.pvc.example.command.CommandSQLException;

/**
 * This is the CreateDbCommand class.
 * 
 * This class is responsible for creating the database that stores the Calendar Servlet's
 * event data.
 * 
 * The command can be tailored to drop the tables if the tables have previously been created.
 * The command can also be tailored to not run the command if the database tables had previously
 * been created.
 */
public class CreateDbCommand implements Command {
	private boolean dropDbIfNecessary = true;
	private boolean doNothingIfDbExists = true;;	

	/**
	 * @see java.lang.Object#Object()
	 */
	public CreateDbCommand() {
		super();
	}

	/**
	 * @see com.ibm.pvc.example.command.Command#execute()
	 */
	public void execute() throws CommandException {
		Connection dbConnection = null;
		Statement statement = null;
	    try {
			dbConnection = EventDbHelper.getConnection();
			statement = dbConnection.createStatement();
			
			boolean
				dbExists = EventDb.doesDbExist(statement);

			if ((dbExists) && (doNothingIfDbExists)) {
				// do nothing!
			}
			else { 	
				if (dropDbIfNecessary) {
					try {
						EventDb.dropTables(statement);
					}
					catch (SQLException sqlException) {
						// Can ignore this exception since the goal is to create the DBs
					}
				}
				EventDb.createTables(statement);
			}
	    }
		catch (SQLException sqlException) {
			throw new CommandSQLException(sqlException);
		}
		catch (Error error) {
			throw error;
		}
		finally {
			DbHelper.closeStatement(statement);
			DbHelper.closeConnection(dbConnection);
		}
	}
	/**
	 * Method isDropDbIfNecessary.
	 * @return boolean
	 */
	public boolean isDropDbIfNecessary() {
		return dropDbIfNecessary;
	}
	/**
	 * Method setDropDbIfNecessary.
	 * @param newDropDbIfNecessary
	 */
	public void setDropDbIfNecessary(boolean newDropDbIfNecessary) {
		this.dropDbIfNecessary = newDropDbIfNecessary;
	}
	/**
	 * Method isDropDbIfNecessary.
	 * @return boolean
	 */
	public boolean isDoNothingIfDbExists() {
		return doNothingIfDbExists;
	}
	/**
	 * Method setDropDbIfNecessary.
	 * @param newDropDbIfNecessary
	 */
	public void setDoNothingIfDbExists(boolean newDoNothingIfDbExists) {
		this.doNothingIfDbExists = newDoNothingIfDbExists;
	}	
}