/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar.view;

import java.util.Calendar;

import javax.servlet.ServletException;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.ibm.pvc.example.calendar.CalendarConstants;
import com.ibm.pvc.example.calendar.CalendarServlet;
import com.ibm.pvc.example.calendar.CalendarServletHelper;
import com.ibm.pvc.example.calendar.controller.DayInfoController;
import com.ibm.pvc.example.calendar.controller.FramesetController;
import com.ibm.pvc.example.calendar.controller.HelpController;
import com.ibm.pvc.example.calendar.controller.MonthInfoController;
import com.ibm.pvc.example.calendar.controller.NewEventController;
import com.ibm.pvc.example.calendar.controller.SettingsController;
import com.ibm.pvc.example.calendar.controller.WeekInfoController;
import com.ibm.pvc.example.calendar.model.EventCategories;
import com.ibm.pvc.example.calendar.model.Settings;
import com.ibm.pvc.example.calendar.model.SettingsDAO;

/**
 * This is the CalendarAppView class.
 * 
 * All concrete Calendar view classes are subclasses of this class.
 * This class provides the methods that are required by the various
 * controller classes to display this UI in either frameset or non-frameset
 * modes and to display context sensitive help.
 */
public abstract class CalendarAppView {

/**
 * @see java.lang.Object#Object()
 */
public CalendarAppView() {
	super();
}

/**
 * Method getTitle.
 * @return String
 */
abstract protected String getTitle();

/**
 * Method outputCompositeView.
 * @param out
 * @throws IOException
 */
protected void outputCompositeView(ServletOutputStream out) throws java.io.IOException {
	out.println("<HTML>");
	out.println("<BASEFONT FACE=\"Verdana, Arial, Helvetica\" SIZE=3>");
	out.println("<HEAD><TITLE>" + getTitle() + "</TITLE>");
	out.println("<META name=\"copyright\" content=\"Copyright (c) 2002 by IBM Corporation\"/>");
	out.println("<META name=\"expires\" content=\"31 December 2000\"/>");
	out.println("</HEAD><BODY LINK=BROWN VLINK=BROWN ALINK=BROWN>");
	out.println("<div style=\"padding: 0; margin: 0; background:orange; link:orange; active:orange; visited:orange \">");
	outputViewHeading(out);
	out.println("</DIV>");
	out.println("<div style=\"overflow: auto; padding: 0; margin: 0; height: 90%\">");
	outputViewContent(out);
	out.println("</DIV>");
	out.println("<div style=\"padding: 0; margin: 0; background:black\">");
	outputViewMenu(out);
	out.println("</DIV>");	
	out.println("</BODY></HTML>");
}
/**
 * Method outputHelpViewFrameset.
 * @param out
 * @throws IOException
 */
public void outputHelpViewFrameset(ServletOutputStream out) throws java.io.IOException {
	out.println("<HTML>");
	out.println("<HEAD><TITLE>" + Resources.BUNDLE.getString(Resources.HEAD_HELP) + "</TITLE>");
	out.println("<META name=\"copyright\" content=\"Copyright (c) 2002 by IBM Corporation\"/>");
	out.println("<META name=\"expires\" content=\"31 December 2000\"/>");
	out.println("</HEAD>");
	out.println("<FRAMESET ROWS=\"*,35\" FRAMEBORDER=0>");
	out.println("   <FRAME NAME=CONTENT SRC=" + CalendarServlet.HELP_URI + "/" + getHelpFileName() + " SCROLLING=YES FRAMEBORDER=0 NORESIZE>");
	out.println("   <FRAME NAME=MENU    SRC=" + HelpController.buildUrl(HelpController.HC_VIEW_MENU) + " SCROLLING=NO FRAMEBORDER=0 NORESIZE>"); 	  
	out.println("</FRAMESET>");
	out.println("</HTML>");
}
/**
 * Method outputHelpViewMenuFrame.
 * @param out
 * @throws IOException
 */
public void outputHelpViewMenuFrame(ServletOutputStream out) throws java.io.IOException {
	out.print("<HTML>");
	out.print("<HEAD><TITLE>");
	out.print(getTitle());
	out.println("</TITLE></HEAD><BODY COLOR=YELLOW BGCOLOR=BLACK>");
	outputViewHelpMenu(out);
	out.println("</BODY></HTML>");
}

/**
 * Method outputView.
 * @param request
 * @param response
 * @throws ServletException
 * @throws IOException
 */
public void outputView(HttpServletRequest request, HttpServletResponse response) throws ServletException, java.io.IOException {
	Settings settings = SettingsDAO.getAppSettings();
	
	ServletOutputStream out = response.getOutputStream();
	try {
		response.setContentType("text/html");
		response.setStatus(response.SC_OK);
		response.setDateHeader("Expires", 0);

		request.getSession().putValue(CalendarConstants.ATTR_CURRENT_VIEW, this);
		if (!settings.isOverflowSupported()) {
			outputViewFrameset(out);
		} else {
			outputCompositeView(out);
		}
	} catch (Exception ex) {
		out.println("<BR>Class: " + getClass().toString());		
		out.println("<BR>Exception:" + ex.toString());
	}
}
/**
 * Method outputViewContent.
 * @param out
 * @throws IOException
 */
protected abstract void outputViewContent(ServletOutputStream out) throws java.io.IOException;
 
/**
 * Method outputViewContentFrame.
 * @param out
 * @throws IOException
 */
public void outputViewContentFrame(ServletOutputStream out) throws java.io.IOException {
	Settings settings = SettingsDAO.getAppSettings();
	out.println("<HTML>");
	out.println("<HEAD><TITLE>" + getTitle() + "</TITLE>");
	out.println("<META name=\"copyright\" content=\"Copyright (c) 2002 by IBM Corporation\"/>");
	out.println("</HEAD><BODY LINK=" + settings.getTitlesFgColor() + " VLINK=" + settings.getTitlesFgColor() + ">");
	outputViewContent(out);
	out.println("</BODY></HTML>");
}
/**
 * Method outputViewFrameset.
 * @param out
 * @throws IOException
 */
public void outputViewFrameset(ServletOutputStream out) throws java.io.IOException {
	out.println("<HTML>");
	out.println("<HEAD><TITLE>" + getTitle() + "</TITLE>");
	out.println("<META name=\"copyright\" content=\"Copyright (c) 2002 by IBM Corporation\"/>");
	out.println("</HEAD>");
	out.println("<FRAMESET ROWS=\"35,*,35\" FRAMEBORDER=0 BORDER=0 FRAMESPACING=0>");
	out.println("   <FRAME NAME=HEADING SRC=" + FramesetController.buildUrl(FramesetController.FSC_VIEW_HEADING) + " SCROLLING=NO FRAMEBORDER=0 BORDER=0 FRAMESPACING=0 NORESIZE>");
	out.println("   <FRAME NAME=CONTENT SRC=" + FramesetController.buildUrl(FramesetController.FSC_VIEW_CONTENT) + " SCROLLING=YES FRAMEBORDER=0 BORDER=0 FRAMESPACING=0 NORESIZE>");
	out.println("   <FRAME NAME=MENU    SRC=" + FramesetController.buildUrl(FramesetController.FSC_VIEW_MENU) + " SCROLLING=NO FRAMEBORDER=0 BORDER=0 FRAMESPACING=0 NORESIZE>"); 	  
	out.println("</FRAMESET>");
	out.println("</HTML>");
}

/**
 * Method outputViewHeading.
 * @param out
 * @throws IOException
 */
protected void outputViewHeading(ServletOutputStream out) throws java.io.IOException {
	Settings settings = SettingsDAO.getAppSettings();
	out.println("<TABLE BGCOLOR=" + settings.getTitlesBgColor() + " BORDER=0 CELLPADDING=0 CELLSPACING=0 WIDTH=100%><TR>");
	out.println("<TD ALIGN=CENTER VALIGN=CENTER WIDTH=100%>");		
	out.println("<FONT SIZE=+1 COLOR=" + settings.getTitlesFgColor() + ">" + getTitle() + "</FONT></TD></TR></TABLE>");
}
/**
 * Method outputViewHeadingFrame.
 * @param out
 * @throws IOException
 */
public void outputViewHeadingFrame(ServletOutputStream out) throws java.io.IOException {
	Settings settings = SettingsDAO.getAppSettings();

	out.println("<HTML>");
	out.println(
		"<HEAD><TITLE>"
			+ getTitle()
			+ "</TITLE></HEAD><BODY COLOR="
			+ settings.getTitlesFgColor()
			+ "  BGCOLOR="
			+ settings.getTitlesBgColor()
			+ "  LINK="
			+ settings.getTitlesBgColor()
			+ " VLINK="
			+ settings.getTitlesBgColor()
			+ ">");
	outputViewHeading(out);
	out.println("</BODY></HTML>");
}
/**
 * Method outputViewHelpOnlyMenu.
 * @param out
 * @throws IOException
 */
public void outputViewHelpOnlyMenu(ServletOutputStream out) throws java.io.IOException {
   out.println("<TABLE BGCOLOR=BLACK COLOR=YELLOW BORDER=0 CELLSPACING=5 CELLPADDING=0 WIDTH=100%><TR>");
   out.println("<TD ALIGN=RIGHT><A HREF=\"" + HelpController.buildUrl(HelpController.HC_VIEW_TOP)      + "\" target=\"_top\"><IMG SRC=\"/PIMImages/help.gif\" ALT=\"" + Resources.BUNDLE.getString(Resources.ACTION_HELP) + "\"></A></TD>");  
   out.println("</TR></TABLE>");

}
/**
 * Method outputViewHelpMenu.
 * @param out
 * @throws IOException
 */
public void outputViewHelpMenu(ServletOutputStream out) throws java.io.IOException {
   out.println("<TABLE BGCOLOR=BLACK COLOR=YELLOW BORDER=0 CELLSPACING=5 CELLPADDING=0 WIDTH=100%><TR>");
   out.println("<TD ALIGN=LEFT WIDTH=50%></TD>"); 
   out.println("<TD ALIGN=RIGHT><A HREF=\"" + CalendarServlet.HELP_URI + "/contents.htm\" target=\"CONTENT\"><IMG SRC=\"/PIMImages/content.gif\" ALT=\"" + Resources.BUNDLE.getString(Resources.ACTION_TOC) + "\"></A></TD>"); 
   out.println("<TD ALIGN=RIGHT><A HREF=\"" + HelpController.buildUrl(HelpController.HC_VIEW_MENU) + "\" onclick=\"parent.history.back();\"><IMG SRC=\"/PIMImages/previous.gif\" ALT=\"" + Resources.BUNDLE.getString(Resources.ACTION_BACK) + "\"></A></TD>"); 
// out.println("<TD ALIGN=RIGHT><A HREF=\"" + HelpController.buildUrl(HelpController.HC_VIEW_MENU) + "\" onclick=\"parent.history.forward();\"><IMG SRC=\"/PIMImages/next.gif\" ALT=\"" + Resources.BUNDLE.getString(Resources.ACTION_FORWARD) + "\"></A></TD>"); 
   out.println("<TD ALIGN=RIGHT><A HREF=\"" + HelpController.buildUrl(HelpController.HC_VIEW_RETURN)      + "\" target=\"_top\"><IMG SRC=\"/PIMImages/close.gif\" ALT=\"" + Resources.BUNDLE.getString(Resources.ACTION_CLOSE) + "\"></A></TD>"); 
   out.println("</TR></TABLE>");

}
/**
 * Method outputViewMainMenu.
 * @param out
 * @param cal
 * @throws IOException
 */
protected void outputViewMainMenu(ServletOutputStream out, Calendar cal) throws java.io.IOException {
   out.println("<TABLE BGCOLOR=BLACK COLOR=YELLOW BORDER=0 CELLSPACING=5 CELLPADDING=0 WIDTH=100%><TR>");
   out.println("<TD><A HREF=\"" + DayInfoController.buildUrl(cal)   + "\" target=\"_top\"><IMG SRC=\"/PIMImages/Day.gif\"  ALT=\"" + Resources.BUNDLE.getString(Resources.ACTION_DAY_VIEW) + "\"></A></TD>");
   out.println("<TD><A HREF=\"" + WeekInfoController.buildUrl(cal)  + "\" target=\"_top\"><IMG SRC=\"/PIMImages/Week.gif\"  ALT=\"" + Resources.BUNDLE.getString(Resources.ACTION_WEEK_VIEW) + "\"></A></TD>");
   out.println("<TD><A HREF=\"" + MonthInfoController.buildUrl(cal) + "\" target=\"_top\"><IMG SRC=\"/PIMImages/Month.gif\" ALT=\"" + Resources.BUNDLE.getString(Resources.ACTION_MONTH_VIEW) + "\"></A></TD>");
   out.println("<TD><A HREF=\"" + DayInfoController.buildUrl(java.util.Calendar.getInstance())   + "\" target=\"_top\"><IMG SRC=\"/PIMImages/Today.gif\" ALT=\"" + Resources.BUNDLE.getString(Resources.ACTION_TODAY) + "\"></A></TD>");
   out.println("<TD><A HREF=\"" + NewEventController.buildUrl(cal)  + "\" target=\"_top\"><IMG SRC=\"/PIMImages/new.gif\" ALT=\"" + Resources.BUNDLE.getString(Resources.ACTION_NEW_EVENT) + "\"></A></TD>");
   out.println("<TD><A HREF=\"" + SettingsController.buildUrl()  + "\" target=\"_top\"><IMG SRC=\"/PIMImages/settings.gif\" ALT=\"" + Resources.BUNDLE.getString(Resources.ACTION_SETTINGS) + "\"></A></TD>");
   out.println("<TD><A HREF=\"" + HelpController.buildUrl(HelpController.HC_VIEW_TOP)      + "\" target=\"_top\"><IMG SRC=\"/PIMImages/help.gif\" ALT=\"" + Resources.BUNDLE.getString(Resources.ACTION_HELP) + "\"></A></TD>");
   out.println("</TR></TABLE>");

}
/**
 * Method outputViewMenu.
 * @param out
 * @throws IOException
 */
protected void outputViewMenu(ServletOutputStream out) throws java.io.IOException {
   out.println("<TABLE BGCOLOR=BLACK COLOR=YELLOW BORDER=0 CELLSPACING=5 CELLPADDING=0 WIDTH=100%><TR>");
   out.println("<TD><A HREF=\"" + DayInfoController.buildUrl()   + "\" target=\"_top\"><IMG SRC=\"/PIMImages/Day.gif\" ALT=\"" + Resources.BUNDLE.getString(Resources.ACTION_DAY_VIEW) + "\"></A></TD>");
   out.println("<TD><A HREF=\"" + WeekInfoController.buildUrl()  + "\" target=\"_top\"><IMG SRC=\"/PIMImages/Week.gif\" ALT=\"" + Resources.BUNDLE.getString(Resources.ACTION_WEEK_VIEW) + "\"></A></TD>");
   out.println("<TD><A HREF=\"" + MonthInfoController.buildUrl() + "\" target=\"_top\"><IMG SRC=\"/PIMImages/Month.gif\" ALT=\"" + Resources.BUNDLE.getString(Resources.ACTION_MONTH_VIEW) + "\"></A></TD>");
   out.println("<TD><A HREF=\"" + DayInfoController.buildUrl(java.util.Calendar.getInstance())   + "\" target=\"_top\"><IMG SRC=\"/PIMImages/Today.gif\" ALT=\"" + Resources.BUNDLE.getString(Resources.ACTION_TODAY) + "\"></A></TD>");
   out.println("<TD><A HREF=\"" + NewEventController.buildUrl()  + "\" target=\"_top\"><IMG SRC=\"/PIMImages/new.gif\" ALT=\"" + Resources.BUNDLE.getString(Resources.ACTION_NEW_EVENT) + "\"></A></TD>");
   out.println("<TD><A HREF=\"" + SettingsController.buildUrl()  + "\" target=\"_top\"><IMG SRC=\"/PIMImages/settings.gif\" ALT=\"" + Resources.BUNDLE.getString(Resources.ACTION_SETTINGS) + "\"></A></TD>");
   out.println("<TD><A HREF=\"" + HelpController.buildUrl(HelpController.HC_VIEW_TOP)      + "\" target=\"_top\"><IMG SRC=\"/PIMImages/help.gif\" ALT=\"" + Resources.BUNDLE.getString(Resources.ACTION_HELP) + "\"></A></TD>"); 
   out.println("</TR></TABLE>");

}
/**
 * Method outputViewMenuFrame.
 * @param out
 * @throws IOException
 */
public void outputViewMenuFrame(ServletOutputStream out) throws java.io.IOException {
	out.println("<HTML>");
	out.println("<HEAD><TITLE>" + getTitle() + "</TITLE></HEAD><BODY COLOR=YELLOW BGCOLOR=BLACK LINK=BLACK VLINK=BLACK>");
	outputViewMenu(out);
	out.println("</BODY></HTML>");
}
/**
 * Method outputEncodedDataValue.
 * @param out
 * @param dataValue
 * @throws IOException
 */
public static  void outputEncodedDataValue(ServletOutputStream out, String dataValue) throws java.io.IOException {
	char[]  charToEncode = { '\"',    '&',     '<',    '>'   };
	String[] charEncoding = { "&quot;","&amp;", "&lt;", "&gt;"};

	char[] valueAsChars = new char[dataValue.length()];
	dataValue.getChars(0, valueAsChars.length, valueAsChars, 0);
	
	for (int i = 0; i < valueAsChars.length; i++) {
		char
			currentChar = valueAsChars[i];
		boolean
			charToEncodeFound = false;
		for (int j = 0; (j < charToEncode.length) && (!charToEncodeFound); j++) {
			if (currentChar == charToEncode[j]) {
				out.print(charEncoding[j]);
				charToEncodeFound = true;
			}
		}
		if (!charToEncodeFound) {
			out.print(currentChar);
		}
	}
}

/**
 * Method getIconNameForCategory.
 * @param categories
 * @return String
 */
public static String getIconNameForCategory(EventCategories categories) {
	String
		iconName = null;	
		
	if (categories.isAppointment()) {
	 	iconName = CalendarViewConstants.APPT_IMG; }
	else if (categories.isBusiness()) {
	 	iconName = CalendarViewConstants.BUSINESS_IMG; }
	else if (categories.isEducation()) {
	 	iconName = CalendarViewConstants.EDUCATION_IMG; }
	else if (categories.isHoliday()) {
	 	iconName = CalendarViewConstants.HOLIDAY_IMG; }
	else if (categories.isMeeting()) {
	 	iconName = CalendarViewConstants.MEETING_IMG; }
	else if (categories.isMiscellaneous()) {
	 	iconName = CalendarViewConstants.MISC_IMG; }
	else if (categories.isOther()) {
	 	iconName = CalendarViewConstants.OTHER_IMG; }
	else if (categories.isPersonal()) {
	 	iconName = CalendarViewConstants.PERSONAL_IMG; }
	else if (categories.isPhoneCall()) {
	 	iconName = CalendarViewConstants.PHONE_CALL_IMG; }
	else if (categories.isSickDay()) {
	 	iconName = CalendarViewConstants.SICK_DAY_IMG; }	
	else if (categories.isSpecialOccasion()) {
	 	iconName = CalendarViewConstants.SPECIAL_IMG; }	 
	else if (categories.isTravel()){
	 	iconName = CalendarViewConstants.TRAVEL_IMG; }	 
	else if (categories.isVacation()) {
	 	iconName = CalendarViewConstants.VACATION_IMG; }	 

	 return iconName;	 		 		 	 		 		 		 		 	

}
/**
 * Method getHelpFileName.
 * @return String
 * @throws IOException
 */
public String getHelpFileName() throws java.io.IOException {
	return ("contents.htm");
}

}
