/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar.view;

import javax.servlet.ServletOutputStream;

import com.ibm.pvc.example.calendar.controller.DeleteEventController;
import com.ibm.pvc.example.calendar.model.Event;

/**
 * This is the DeleteEventConfirmationView class.
 * 
 * This class handles the rendering of the 1/4 VGA Confirmation Panel 
 * that prompts the user to ensure that they truly want to delete an event.
 * 
 * Instances of this class are contructed with the "to be deleted" event passed as a parameter..
 */
public class DeleteEventConfirmationView extends CalendarAppView {
	private Event event;

	/**
	 * Method DeleteEventConfirmationView.
	 * @param event
	 */
	public DeleteEventConfirmationView(Event event) {
		super();
		this.event = event;
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#getTitle()
	 */
	protected String getTitle() {
		return Resources.getNlsString(Resources.HEAD_DEL_EVENT);
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#outputViewContent(ServletOutputStream)
	 */
	protected void outputViewContent(ServletOutputStream out)
		throws java.io.IOException {
		out.println("<CE>" + Resources.BUNDLE.getString(Resources.TEXT_PERM_DEL) + "</CE>");
		out.println("<BR>");
		out.println("<CE>" + Resources.BUNDLE.getString(Resources.TEXT_DEL_CONFIRM) + "</CE>");
		out.println("<BR>");
		out.println(
			"<FORM NAME=DeleteForm ACTION=\""
				+ DeleteEventController.buildUrl(event)
				+ "\" METHOD=POST TARGET=\"_top\">");
		out.println("<INPUT TYPE=SUBMIT VALUE=\"" + Resources.BUNDLE.getString(Resources.ACTION_YES) + "\" NAME=\"YES_DELETE\">");
		out.println("<INPUT TYPE=SUBMIT VALUE=\"" + Resources.BUNDLE.getString(Resources.ACTION_NO) + "\" NAME=\"NO_DELETE\">");
		out.println("</FORM>");
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#outputViewMenu(ServletOutputStream)
	 */
	protected void outputViewMenu(ServletOutputStream out)
		throws java.io.IOException {
		outputViewHelpOnlyMenu(out);
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#getHelpFileName()
	 */
	public String getHelpFileName() throws java.io.IOException {
		return (CalendarViewConstants.HELP_DELETE);
	}	
}