/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar.view;

import java.text.DateFormatSymbols;
import java.util.Calendar;

import javax.servlet.ServletOutputStream;

import com.ibm.pvc.example.calendar.CalendarConstants;
import com.ibm.pvc.example.calendar.model.Event;
import com.ibm.pvc.example.calendar.model.EventCategories;

/**
 * This is the abstract EventView class.
 *
 * The NewEventView and UpdateEventView classes are subclasses of this class.
 * This class is responsible for handling the common tasks associated with those
 * two classes.  
 * 
 * Instances of this class are contructed with the event to render passed as a parameter..
 */
public abstract class EventView extends CalendarAppView {
	protected Event event;

	/**
	 * Method EventView.
	 * @param event
	 */
	public EventView(Event event) {
		super();
		this.event = event;
	}
	/**
	 * Method addFormButtons.
	 * @param out
	 * @throws IOException
	 */
	protected abstract void addFormButtons(ServletOutputStream out)
		throws java.io.IOException;
	/**
	 * Method getEvent.
	 * @return Event
	 */
	public Event getEvent() {
		return this.event;
	}

	/**
	 * Method getEventFormAction.
	 * @return String
	 */
	protected abstract String getEventFormAction();

	/**
	 * Method outputEventCommonArea.
	 * @param out
	 * @throws IOException
	 */
	public void outputEventCommonArea(ServletOutputStream out)
		throws java.io.IOException {
		DateFormatSymbols dfs = new DateFormatSymbols(java.util.Locale.getDefault());

		String[] months = dfs.getMonths();
		String[] amPmStrings = dfs.getAmPmStrings();		
		
		Calendar evtStart = event.getEvtStart(), evtEnd = event.getEvtEnd();

		int year = evtStart.get(Calendar.YEAR),
			month = evtStart.get(Calendar.MONTH),
			day = evtStart.get(Calendar.DAY_OF_MONTH),
			hour = evtStart.get(Calendar.HOUR),
			minute = evtStart.get(Calendar.MINUTE),
			am_pm = evtStart.get(Calendar.AM_PM);

		long duration = event.getDurationInMinutes();

		out.print("<FORM NAME=\"EventForm\" ACTION=\"");
		out.print(getEventFormAction());
		out.print( "\" METHOD=POST TARGET=\"_top\">");
		out.print("<TABLE><TR>");
		out.print("<TD>" + Resources.getNlsString(Resources.FLD_SUMMARY) + "</TD>");
		out.print("<TD><INPUT TYPE=TEXT NAME=");
		out.print(CalendarConstants.PARM_SUMMARY);
		out.print(" VALUE=\"");
		CalendarAppView.outputEncodedDataValue(out, event.getSummary());
		out.print("\" SIZE=18></TD></TR><TR>");
		out.println("<TD>" + Resources.getNlsString(Resources.FLD_TYPE) + "</TD>");
		out.println("<TD>");
		String[] cats =
			{
				EventCategories.APPOINTMENT,
				EventCategories.BUSINESS,
				EventCategories.EDUCATION,
				EventCategories.HOLIDAY,
				EventCategories.MEETING,
				EventCategories.MISCELLANEOUS,
				EventCategories.PERSONAL,
				EventCategories.PHONE_CALL,
				EventCategories.SICK_DAY,
				EventCategories.SPECIAL_OCCASION,
				EventCategories.TRAVEL,
				EventCategories.VACATION };

		out.println("<SELECT NAME=\"Categories\">");
		for (int i = 0; i < cats.length; i++) {
			EventCategories
				categories = event.getCategories();
			
			String
				catString = (categories != null) ? categories.asString() : "";	
 				
			boolean
				catSelect = catString.startsWith(cats[i]);
 			
			out.println(
				"<OPTION VALUE=\""
					+ cats[i]
					+ "\""
					+ ((catSelect) ? " SELECTED" : "")
					+ ">"
					+ cats[i]
					+ "</OPTION>");
		}
		out.println("</SELECT>");
		out.println("</TD>");
		out.println("</TR><TR>");
		out.println(
			"<TD>" + Resources.getNlsString(Resources.FLD_DATE) + "</TD>");
		out.println("</TR><TR>");			
		out.println("<TD COLSPAN=4><TABLE><TR>");
		out.println("<TD>");

		out.println("<SELECT NAME=\"Month\">");
		for (int i = 0; i < months.length-1; i++) {
			out.println(
				"<OPTION VALUE=\""
					+ i
					+ "\""
					+ ((i == month) ? " SELECTED" : "")
					+ ">"
					+ months[i]
					+ "</OPTION>");
		}
		out.println("</SELECT>");
		out.println("</TD>");
		out.println("<TD>");
		out.println("<SELECT NAME=\"Day\">");
		for (int i = 1; i <= 31; i++) {
			out.println(
				"<OPTION VALUE=\""
					+ i
					+ "\" "
					+ ((i == day) ? " SELECTED" : "")
					+ ">"
					+ i
					+ "</OPTION>");
		}
		out.println("</SELECT>");
		out.println("</TD>");
		out.println("<TD>");
		out.println("<SELECT NAME=\"Year\">");
		for (int i = year - 10; i < year + 15; i++) {
			out.println(
				"<OPTION VALUE=\""
					+ i
					+ "\""
					+ ((i == year) ? " SELECTED" : "")
					+ ">"
					+ i
					+ "</OPTION>");
		}
		out.println("</SELECT>");
		out.println("</TD>");
		out.println("</TR></TABLE></TD>");
		out.println("</TR><TR>");
		out.println("<TD>" + Resources.getNlsString(Resources.FLD_START_TIME) + "</TD>");
		out.println("</TR><TR>");
		out.println("<TD COLSPAN=4>");				
		out.println("<TABLE BORDER=0><TR>");
		out.println(
			"<TD><INPUT TYPE=RADIO NAME=EventType VALUE=\"AllDayEvent\" "
				+ ((evtEnd == null) ? " CHECKED" : "")
				+ "></TD><TD>" + Resources.getNlsString(Resources.FLD_ALL_DAY));
		out.println("</TD>");
		out.println("</TR><TR>");
		out.println(
			"<TD><INPUT TYPE=RADIO NAME=EventType VALUE=\"TimedEvent\" "
				+ ((evtEnd != null) ? " CHECKED" : "")
				+ "></TD><TD>");
		out.println("<SELECT NAME=\"StartHour\">");
		for (int i = 1; i <= 12; i++) {
			out.println(
				"<OPTION VALUE=\""
					+ ((i != 12) ? i : 0)
					+ "\" "
					+ ((((i != 12) ? i : 0) == hour) ? "SELECTED" : "")
					+ ">"
					+ i
					+ " </OPTION>");
		}		
		out.println("</SELECT>");
		out.println("<SELECT NAME=\"StartMinute\">");
		for (int i = 0; i < 60; i = i + 1) 
			{
			out.println(
				"<OPTION VALUE=\""
					+ i
					+ "\" "
					+ ((i == minute) ? " SELECTED" : "")
					+ ">"
					+ ((i < 10) ? "0" : "")
					+ i
					+ "</OPTION>");
		}
		out.println("</SELECT>");

		String[] amPmConstants = { "AM", "PM" };
		out.println("<SELECT NAME=\"StartAmPm\">");
		for (int i = 0; i < amPmConstants.length; i++) {
			out.println(
				"<OPTION VALUE=\""
					+ amPmConstants[i]
					+ "\""
					+ ((i == am_pm) ? " SELECTED" : "")
					+ " >"
					+ amPmStrings[i]
					+ "</OPTION>");
		}
		out.println("</SELECT>");

		out.println("</TD></TR><TR>");
		out.println("<TD></TD><TD>" + Resources.getNlsString(Resources.FLD_DURATION));
		out.println("<SELECT NAME=\"Duration\">");
		for (int i = 0; i < Math.max(120, duration); i = i+5) {
			out.println(
				"<OPTION VALUE=\""
					+ i
					+ "\""
					+ ((i == duration) ? " SELECTED" : "")
					+ ">"
					+ i
					+ "</OPTION>");
		}
		out.println("</SELECT>");
		out.println(Resources.BUNDLE.getString(Resources.TEXT_MINUTES));
		out.println("</TD>");		
		out.println("</TR></TABLE>");
		out.println("</TD>");
		out.println("</TR><TR>");
		out.println("<TD>" + Resources.getNlsString(Resources.FLD_DETAILS) + "</TD>");
		out.print("<TD><TEXTAREA NAME=\"" + CalendarConstants.PARM_DETAILS + "\" COLS=18 ROWS=4>");
		CalendarAppView.outputEncodedDataValue(out, event.getDetails());
		out.print("</TEXTAREA></TD>");
		out.println("</TR></TABLE>");
		addFormButtons(out);
		out.println("</FORM>");
	}

	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#outputViewContent(ServletOutputStream)
	 */
	protected void outputViewContent(ServletOutputStream out)
		throws java.io.IOException {
		outputEventCommonArea(out);
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#outputViewMenu(ServletOutputStream)
	 */
	protected void outputViewMenu(ServletOutputStream out)
		throws java.io.IOException {
		outputViewHelpOnlyMenu(out);
	}

	/**
	 * Method setEvent.
	 * @param newEvent
	 */
	public void setEvent(Event newEvent) {
		this.event = newEvent;
	}
}