/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar.view;

import java.text.DateFormatSymbols;
import java.util.Calendar;

import javax.servlet.ServletOutputStream;

import com.ibm.pvc.example.calendar.CalendarServletHelper;
import com.ibm.pvc.example.calendar.controller.DateSelectionController;
import com.ibm.pvc.example.calendar.controller.DayInfoController;
import com.ibm.pvc.example.calendar.controller.MonthInfoController;
import com.ibm.pvc.example.calendar.model.DayInfo;
import com.ibm.pvc.example.calendar.model.Settings;
import com.ibm.pvc.example.calendar.model.SettingsDAO;

/**
 * This is the MonthInfoView class.
 * 
 * This class handles the rendering of the 1/4 VGA Monthly View in the Calendar Servlet.
 * 
 * Instances of this class are contructed with both a day in the month (used to determine which 
 * month to display) and all the information to be displayed for the days in that month
 * passed as parameters.
 */
public class MonthInfoView extends CalendarAppView {
	private Calendar currentDate;
	private DayInfo[] dayInfos;

	/**
	 * Method MonthInfoView.
	 * @param currentDate
	 * @param dayInfos
	 */
	public MonthInfoView(Calendar currentDate, DayInfo[] dayInfos) {
		super();
		this.currentDate = currentDate;
		this.dayInfos = dayInfos;
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#getTitle()
	 */
	protected String getTitle() {

		return (new DateFormatSymbols()).getMonths()[currentDate.get(Calendar.MONTH)]
			+ " "
			+ currentDate.get(Calendar.YEAR);
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#outputViewContent(ServletOutputStream)
	 */
	protected void outputViewContent(ServletOutputStream out)
		throws java.io.IOException {
		DateFormatSymbols dfs = new DateFormatSymbols(java.util.Locale.getDefault());
		String weekdays[] = dfs.getShortWeekdays();

		String[] months = dfs.getMonths();

		Calendar monthDayObj = (Calendar) currentDate.clone();
		monthDayObj.setLenient(false);

		monthDayObj.set(Calendar.DATE, 1);

		int month = monthDayObj.get(Calendar.MONTH);

		int year = monthDayObj.get(Calendar.YEAR);

		int daysInWeek = monthDayObj.getMaximum(Calendar.DAY_OF_WEEK);
		int firstDayOfWeek = monthDayObj.getMinimum(Calendar.DAY_OF_WEEK);

		int nextDayInfoIndex = 0;
		DayInfo nextDayInfo = null;
		Calendar nextDayInfoCal = Calendar.getInstance();

		out.print("<TABLE BORDER=1 WIDTH=100%>");
		for (int i = firstDayOfWeek; i <= daysInWeek; i++) {
			out.print("<TH WIDTH=" + (100 / daysInWeek) + "% ALIGN=CENTER>");
			out.print(weekdays[i]);
			out.println("</TH>");
		}

		int currentWeekday = firstDayOfWeek;
		int firstWeekdayOfMonth = monthDayObj.get(Calendar.DAY_OF_WEEK);
		int firstDayOfMonth = monthDayObj.getMinimum(Calendar.DAY_OF_MONTH);
		int lastDayOfMonth = monthDayObj.getActualMaximum(Calendar.DAY_OF_MONTH);

		out.println("<TR>");
		for (int i = firstDayOfWeek; i < firstWeekdayOfMonth; i++) {
			out.print("<TD BORDER=0></TD>");
			currentWeekday++;
		}
		Calendar dayOfMonthCal = Calendar.getInstance();
		DayInfo currentDayInfo = null;

		String iconName = null;

		for (int i = firstDayOfMonth;
			i <= lastDayOfMonth;
			i++, monthDayObj.add(Calendar.DATE, 1)) {
			out.print("<TD ALIGN=RIGHT VALIGN=TOP HEIGHT=15%><A HREF=\"");
			out.print(DayInfoController.buildUrl(monthDayObj));
			out.print("\" ALINK=BLACK LINK=BLACK VLINK=BLACK TARGET=\"_top\">");
			out.print(Integer.toString(i));

			dayOfMonthCal.setTime(monthDayObj.getTime());

			currentDayInfo =
				CalendarServletHelper.getDayInfoForDay(dayInfos, dayOfMonthCal);
			if (currentDayInfo != null) {
				if (currentDayInfo.containsAllDayEvent()) {
					iconName = "calendar_am_pm.gif";
				}
				else if (currentDayInfo.containsEventInAm()) {
					if (currentDayInfo.containsEventInPm()) {
						iconName = "calendar_am_pm.gif";
					}
					else {
						iconName = "calendar_am.gif";
					}

				}
				else if (currentDayInfo.containsEventInPm()) {
					iconName = "calendar_pm.gif";
				}
				else {
					iconName = null;
				}

				out.print(
					((iconName != null)
						? "<BR><IMG BORDER=0 SRC=\"/PIMImages/" + iconName + "\">"
						: ""));

			}
			out.print("</A>");
			out.print("</TD>");
			if (currentWeekday++ >= daysInWeek) {
				out.println("</TR></TR>");
				currentWeekday = firstDayOfWeek;
			}
		}

		out.print("</TABLE>");

		out.println(
			"<FORM NAME=\"DateSelectFormForm\" ACTION=\""
				+ DateSelectionController.buildUrl(monthDayObj)
				+ "\" METHOD=POST TARGET=\"_top\">");

		out.println("<TABLE><TR><TD>");
		out.println("<SELECT NAME=\"Month\">");
		for (int i = 0; i < months.length-1; i++) {
			out.println(
				"<OPTION VALUE=\""
					+ i
					+ "\""
					+ ((i == month) ? "SELECTED" : "")
					+ " >"
					+ months[i]
					+ "</OPTION>");
		}
		out.println("</SELECT>");
		out.println("</TD>");
		out.println("<TD>");
		out.println("<SELECT NAME=\"Year\">");
		for (int i = year - 10; i < year + 15; i++) {
			out.println(
				"<OPTION VALUE=\""
					+ i
					+ "\""
					+ ((i == year) ? "SELECTED" : "")
					+ " >"
					+ i
					+ "</OPTION>");
		}
		out.println("</SELECT>");
		out.println("</TD><TD>");
		out.println("<INPUT TYPE=SUBMIT VALUE=\"" + Resources.BUNDLE.getString(Resources.ACTION_GO) + "\" NAME=\"SUBMIT\">");
		out.println("</TD></TR></TABLE>");

		out.println("</FORM>");
		out.println("</CENTER>");
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#outputViewHeading(ServletOutputStream)
	 */
	protected void outputViewHeading(ServletOutputStream out)
		throws java.io.IOException {
		Settings settings = SettingsDAO.getAppSettings();	
				
		Calendar cal = (Calendar) currentDate.clone();

		cal.add(Calendar.MONTH, -1);

		out.println(
			"<TABLE BGCOLOR="
				+ settings.getTitlesBgColor()
				+ " BORDER=0 CELLPADDING=0 CELLSPACING=0 WIDTH=100%><TR>");
		out.println("<TD ALIGN=LEFT VALIGN=CENTER>");
		out.print(
			"<A HREF=\"" + MonthInfoController.buildUrl(cal) + "\" target=\"_top\">");
		out.print(
			"<IMG SRC=\"/PIMImages/Title-bar_arrow-left.gif\" ALT=\"" + Resources.BUNDLE.getString(Resources.ACTION_P_MONTH) + "\"></A></TD>");

		cal.add(Calendar.MONTH, +1);

		out.println("<TD ALIGN=CENTER VALIGN=CENTER WIDTH=*>");
		out.println(
			"<FONT SIZE=+1 COLOR="
				+ settings.getTitlesFgColor()
				+ ">"
				+ getTitle()
				+ "</FONT></TD>");

		cal.add(Calendar.MONTH, +1);

		out.println("<TD ALIGN=RIGHT VALIGN=CENTER>");
		out.print(
			"<A HREF=\"" + MonthInfoController.buildUrl(cal) + "\" target=\"_top\">");
		out.print(
			"<IMG SRC=\"/PIMImages/Title-bar_arrow-right.gif\" ALT=\"" + Resources.BUNDLE.getString(Resources.ACTION_N_MONTH) + "\"></A></TD></TR></TABLE>");
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#outputViewMenu(ServletOutputStream)
	 */
	protected void outputViewMenu(ServletOutputStream out)
		throws java.io.IOException {
		outputViewMainMenu(out, this.currentDate);
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#getHelpFileName()
	 */
	public String getHelpFileName() throws java.io.IOException {
		return (CalendarViewConstants.HELP_IDH_MONTHLY);
	}	
}