/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar.view;

import javax.servlet.ServletOutputStream;

import com.ibm.pvc.example.calendar.controller.DeleteEventController;
import com.ibm.pvc.example.calendar.controller.UpdateEventController;
import com.ibm.pvc.example.calendar.model.Event;

/**
 * This is the UpdateEventView class.
 *	
 * This class handles the rendering of the 1/4 VGA View of the form that users fill in
 * to update a pre-existing event in the calendar.
 * 
 * Instances of this class are contructed passed in the event to be used when contructing 
 * the "Update Event" form to render. 
 */
public class UpdateEventView extends EventView {

	/**
	 * @see com.ibm.pvc.example.calendar.view.EventView#EventView(Event)
	 */
	public UpdateEventView(Event event) {
		super(event);
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.EventView#addFormButtons(ServletOutputStream)
	 */
	protected void addFormButtons(ServletOutputStream out)
		throws java.io.IOException {
		out.println("<INPUT TYPE=SUBMIT VALUE=\"" + Resources.BUNDLE.getString(Resources.ACTION_MOD_EVENT) +  "\" NAME=\"SUBMIT\"  target=\"_top\">");
		out.println("<INPUT TYPE=SUBMIT VALUE=\"" + Resources.BUNDLE.getString(Resources.ACTION_CANCEL) +  "\" NAME=\"CANCEL\"  target=\"_top\">");
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.EventView#getEventFormAction()
	 */
	protected String getEventFormAction() {
		return UpdateEventController.buildUrl(event);
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#getTitle()
	 */
	protected String getTitle() {
		return Resources.getNlsString(Resources.HEAD_UPDATE_EVENT);
	}


	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#outputViewContent(ServletOutputStream)
	 */
	protected void outputViewContent(ServletOutputStream out)
		throws java.io.IOException {
		outputEventCommonArea(out);
		out.println(
			"<FORM NAME=DeleteForm ACTION=\""
				+ DeleteEventController.buildUrl(event)
				+ "\" METHOD=POST TARGET=\"_top\">");
		out.println("<INPUT TYPE=SUBMIT VALUE=\"Delete\" NAME=\"DELETE\"  target=\"_top\">");
		out.println("</FORM>");
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#outputViewMenu(ServletOutputStream)
	 */
	protected void outputViewMenu(ServletOutputStream out)
		throws java.io.IOException {
		outputViewHelpOnlyMenu(out);
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#getHelpFileName()
	 */
	public String getHelpFileName() throws java.io.IOException {
		return (CalendarViewConstants.HELP_IDH_UPDATE);
	}	
}